# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nidmm.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import session_pb2 as session__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0bnidmm.proto\x12\nnidmm_grpc\x1a\rsession.proto\"2\n\x0c\x41\x62ortRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"\x1f\n\rAbortResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xa5\x01\n\x1e\x43heckAttributeViBooleanRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x30\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\x1a.nidmm_grpc.NiDmmAttribute\x12\x17\n\x0f\x61ttribute_value\x18\x04 \x01(\x08\"1\n\x1f\x43heckAttributeViBooleanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x83\x02\n\x1c\x43heckAttributeViInt32Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x30\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\x1a.nidmm_grpc.NiDmmAttribute\x12@\n\x0f\x61ttribute_value\x18\x04 \x01(\x0e\x32%.nidmm_grpc.NiDmmInt32AttributeValuesH\x00\x12\x1d\n\x13\x61ttribute_value_raw\x18\x05 \x01(\x11H\x00\x42\x16\n\x14\x61ttribute_value_enum\"/\n\x1d\x43heckAttributeViInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xd5\x02\n\x1d\x43heckAttributeViReal64Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x30\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\x1a.nidmm_grpc.NiDmmAttribute\x12\x41\n\x0f\x61ttribute_value\x18\x04 \x01(\x0e\x32&.nidmm_grpc.NiDmmReal64AttributeValuesH\x00\x12\x1d\n\x13\x61ttribute_value_raw\x18\x05 \x01(\x01H\x00\x12N\n\x16\x61ttribute_value_mapped\x18\x06 \x01(\x0e\x32,.nidmm_grpc.NiDmmReal64AttributeValuesMappedH\x00\x42\x16\n\x14\x61ttribute_value_enum\"0\n\x1e\x43heckAttributeViReal64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xbd\x01\n\x1e\x43heckAttributeViSessionRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x30\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\x1a.nidmm_grpc.NiDmmAttribute\x12/\n\x0f\x61ttribute_value\x18\x04 \x01(\x0b\x32\x16.nidevice_grpc.Session\"1\n\x1f\x43heckAttributeViSessionResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xa8\x01\n\x1d\x43heckAttributeViStringRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x30\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\x1a.nidmm_grpc.NiDmmAttribute\x12\x1b\n\x13\x61ttribute_value_raw\x18\x04 \x01(\t\"0\n\x1e\x43heckAttributeViStringResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"7\n\x11\x43learErrorRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"$\n\x12\x43learErrorResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"E\n\x1f\x43learInterchangeWarningsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"2\n ClearInterchangeWarningsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"2\n\x0c\x43loseRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"\x1f\n\rCloseResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x83\x01\n\x1b\x43onfigureACBandwidthRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x1f\n\x17\x61\x63_minimum_frequency_hz\x18\x02 \x01(\x01\x12\x1f\n\x17\x61\x63_maximum_frequency_hz\x18\x03 \x01(\x01\".\n\x1c\x43onfigureACBandwidthResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"]\n\x1e\x43onfigureADCCalibrationRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x17\n\x0f\x61\x64\x63_calibration\x18\x02 \x01(\x11\"1\n\x1f\x43onfigureADCCalibrationResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"Z\n\x1c\x43onfigureAutoZeroModeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x16\n\x0e\x61uto_zero_mode\x18\x02 \x01(\x11\"/\n\x1d\x43onfigureAutoZeroModeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\\\n\x1d\x43onfigureCableCompTypeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x17\n\x0f\x63\x61\x62le_comp_type\x18\x02 \x01(\x11\"0\n\x1e\x43onfigureCableCompTypeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"[\n\x1d\x43onfigureCurrentSourceRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x16\n\x0e\x63urrent_source\x18\x02 \x01(\x01\"0\n\x1e\x43onfigureCurrentSourceResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"h\n ConfigureFixedRefJunctionRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12 \n\x18\x66ixed_reference_junction\x18\x02 \x01(\x01\"3\n!ConfigureFixedRefJunctionResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xba\x01\n%ConfigureFrequencyVoltageRangeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12:\n\rvoltage_range\x18\x02 \x01(\x0e\x32!.nidmm_grpc.FrequencyVoltageRangeH\x00\x12\x1b\n\x11voltage_range_raw\x18\x03 \x01(\x01H\x00\x42\x14\n\x12voltage_range_enum\"8\n&ConfigureFrequencyVoltageRangeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"i\n ConfigureMeasCompleteDestRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12!\n\x19meas_complete_destination\x18\x02 \x01(\x11\"3\n!ConfigureMeasCompleteDestResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"d\n!ConfigureMeasCompleteSlopeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x1b\n\x13meas_complete_slope\x18\x02 \x01(\x11\"4\n\"ConfigureMeasCompleteSlopeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xec\x01\n#ConfigureMeasurementAbsoluteRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x34\n\x14measurement_function\x18\x02 \x01(\x0e\x32\x14.nidmm_grpc.FunctionH\x00\x12\"\n\x18measurement_function_raw\x18\x03 \x01(\x11H\x00\x12\r\n\x05range\x18\x04 \x01(\x01\x12\x1b\n\x13resolution_absolute\x18\x05 \x01(\x01\x42\x1b\n\x19measurement_function_enum\"6\n$ConfigureMeasurementAbsoluteResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xe8\x01\n!ConfigureMeasurementDigitsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x34\n\x14measurement_function\x18\x02 \x01(\x0e\x32\x14.nidmm_grpc.FunctionH\x00\x12\"\n\x18measurement_function_raw\x18\x03 \x01(\x11H\x00\x12\r\n\x05range\x18\x04 \x01(\x01\x12\x19\n\x11resolution_digits\x18\x05 \x01(\x01\x42\x1b\n\x19measurement_function_enum\"4\n\"ConfigureMeasurementDigitsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xe0\x03\n\x1a\x43onfigureMultiPointRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x31\n\rtrigger_count\x18\x02 \x01(\x0e\x32\x18.nidmm_grpc.TriggerCountH\x00\x12\x1b\n\x11trigger_count_raw\x18\x03 \x01(\x11H\x00\x12/\n\x0csample_count\x18\x04 \x01(\x0e\x32\x17.nidmm_grpc.SampleCountH\x01\x12\x1a\n\x10sample_count_raw\x18\x05 \x01(\x11H\x01\x12\x33\n\x0esample_trigger\x18\x06 \x01(\x0e\x32\x19.nidmm_grpc.SampleTriggerH\x02\x12\x1c\n\x12sample_trigger_raw\x18\x07 \x01(\x11H\x02\x12\x35\n\x0fsample_interval\x18\x08 \x01(\x0e\x32\x1a.nidmm_grpc.SampleIntervalH\x03\x12\x1d\n\x13sample_interval_raw\x18\t \x01(\x01H\x03\x42\x14\n\x12trigger_count_enumB\x13\n\x11sample_count_enumB\x15\n\x13sample_trigger_enumB\x16\n\x14sample_interval_enum\"-\n\x1b\x43onfigureMultiPointResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xb6\x01\n\x1e\x43onfigureOffsetCompOhmsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x37\n\x10offset_comp_ohms\x18\x02 \x01(\x0e\x32\x1b.nidmm_grpc.CompensatedOhmsH\x00\x12\x1e\n\x14offset_comp_ohms_raw\x18\x03 \x01(\x11H\x00\x42\x17\n\x15offset_comp_ohms_enum\"1\n\x1f\x43onfigureOffsetCompOhmsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"s\n#ConfigureOpenCableCompValuesRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x13\n\x0b\x63onductance\x18\x02 \x01(\x01\x12\x13\n\x0bsusceptance\x18\x03 \x01(\x01\"6\n$ConfigureOpenCableCompValuesResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xd4\x01\n\"ConfigurePowerLineFrequencyRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x43\n\x17power_line_frequency_hz\x18\x02 \x01(\x0e\x32 .nidmm_grpc.PowerLineFrequenciesH\x00\x12%\n\x1bpower_line_frequency_hz_raw\x18\x03 \x01(\x01H\x00\x42\x1e\n\x1cpower_line_frequency_hz_enum\"5\n#ConfigurePowerLineFrequencyResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"l\n\x19\x43onfigureRTDCustomRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\r\n\x05rtd_a\x18\x02 \x01(\x01\x12\r\n\x05rtd_b\x18\x03 \x01(\x01\x12\r\n\x05rtd_c\x18\x04 \x01(\x01\",\n\x1a\x43onfigureRTDCustomResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xa7\x01\n\x17\x43onfigureRTDTypeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\'\n\x08rtd_type\x18\x02 \x01(\x0e\x32\x13.nidmm_grpc.RtdTypeH\x00\x12\x16\n\x0crtd_type_raw\x18\x03 \x01(\x11H\x00\x12\x16\n\x0ertd_resistance\x18\x04 \x01(\x01\x42\x0f\n\rrtd_type_enum\"*\n\x18\x43onfigureRTDTypeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xc6\x01\n\"ConfigureSampleTriggerSlopeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12;\n\x14sample_trigger_slope\x18\x02 \x01(\x0e\x32\x1b.nidmm_grpc.SampleTrigSlopeH\x00\x12\"\n\x18sample_trigger_slope_raw\x18\x03 \x01(\x11H\x00\x42\x1b\n\x19sample_trigger_slope_enum\"5\n#ConfigureSampleTriggerSlopeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"q\n$ConfigureShortCableCompValuesRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x12\n\nresistance\x18\x02 \x01(\x01\x12\x11\n\treactance\x18\x03 \x01(\x01\"7\n%ConfigureShortCableCompValuesResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x88\x01\n ConfigureThermistorCustomRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0cthermistor_a\x18\x02 \x01(\x01\x12\x14\n\x0cthermistor_b\x18\x03 \x01(\x01\x12\x14\n\x0cthermistor_c\x18\x04 \x01(\x01\"3\n!ConfigureThermistorCustomResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"]\n\x1e\x43onfigureThermistorTypeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x17\n\x0fthermistor_type\x18\x02 \x01(\x11\"1\n\x1f\x43onfigureThermistorTypeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xd1\x02\n\x1c\x43onfigureThermocoupleRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x39\n\x11thermocouple_type\x18\x02 \x01(\x0e\x32\x1c.nidmm_grpc.ThermocoupleTypeH\x00\x12\x1f\n\x15thermocouple_type_raw\x18\x03 \x01(\x11H\x00\x12P\n\x17reference_junction_type\x18\x04 \x01(\x0e\x32-.nidmm_grpc.ThermocoupleReferenceJunctionTypeH\x01\x12%\n\x1breference_junction_type_raw\x18\x05 \x01(\x11H\x01\x42\x18\n\x16thermocouple_type_enumB\x1e\n\x1creference_junction_type_enum\"/\n\x1d\x43onfigureThermocoupleResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"]\n\x1e\x43onfigureTransducerTypeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x17\n\x0ftransducer_type\x18\x02 \x01(\x11\"1\n\x1f\x43onfigureTransducerTypeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x8e\x02\n\x17\x43onfigureTriggerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x33\n\x0etrigger_source\x18\x02 \x01(\x0e\x32\x19.nidmm_grpc.TriggerSourceH\x00\x12\x1c\n\x12trigger_source_raw\x18\x03 \x01(\x11H\x00\x12\x32\n\rtrigger_delay\x18\x04 \x01(\x0e\x32\x19.nidmm_grpc.TriggerDelaysH\x01\x12\x1b\n\x11trigger_delay_raw\x18\x05 \x01(\x01H\x01\x42\x15\n\x13trigger_source_enumB\x14\n\x12trigger_delay_enum\"*\n\x18\x43onfigureTriggerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xa8\x01\n\x1c\x43onfigureTriggerSlopeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x31\n\rtrigger_slope\x18\x02 \x01(\x0e\x32\x18.nidmm_grpc.TriggerSlopeH\x00\x12\x1b\n\x11trigger_slope_raw\x18\x03 \x01(\x11H\x00\x42\x14\n\x12trigger_slope_enum\"/\n\x1d\x43onfigureTriggerSlopeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xf6\x01\n#ConfigureWaveformAcquisitionRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x34\n\x14measurement_function\x18\x02 \x01(\x0e\x32\x14.nidmm_grpc.FunctionH\x00\x12\"\n\x18measurement_function_raw\x18\x03 \x01(\x11H\x00\x12\r\n\x05range\x18\x04 \x01(\x01\x12\x0c\n\x04rate\x18\x05 \x01(\x01\x12\x17\n\x0fwaveform_points\x18\x06 \x01(\x11\x42\x1b\n\x19measurement_function_enum\"6\n$ConfigureWaveformAcquisitionResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"a\n ConfigureWaveformCouplingRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x19\n\x11waveform_coupling\x18\x02 \x01(\x11\"3\n!ConfigureWaveformCouplingResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x9e\x01\n\x0e\x43ontrolRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x33\n\x0e\x63ontrol_action\x18\x02 \x01(\x0e\x32\x19.nidmm_grpc.ControlCommitH\x00\x12\x1c\n\x12\x63ontrol_action_raw\x18\x03 \x01(\x11H\x00\x42\x15\n\x13\x63ontrol_action_enum\"!\n\x0f\x43ontrolResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"4\n\x0e\x44isableRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"!\n\x0f\x44isableResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"O\n)ExportAttributeConfigurationBufferRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"S\n*ExportAttributeConfigurationBufferResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x15\n\rconfiguration\x18\x02 \x01(\x0c\"`\n\'ExportAttributeConfigurationFileRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x11\n\tfile_path\x18\x02 \x01(\t\":\n(ExportAttributeConfigurationFileResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x92\x01\n\x0c\x46\x65tchRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12-\n\x0cmaximum_time\x18\x02 \x01(\x0e\x32\x15.nidmm_grpc.TimeLimitH\x00\x12\x1a\n\x10maximum_time_raw\x18\x03 \x01(\x11H\x00\x42\x13\n\x11maximum_time_enum\"0\n\rFetchResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0f\n\x07reading\x18\x02 \x01(\x01\"\xb0\x01\n\x16\x46\x65tchMultiPointRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12-\n\x0cmaximum_time\x18\x02 \x01(\x0e\x32\x15.nidmm_grpc.TimeLimitH\x00\x12\x1a\n\x10maximum_time_raw\x18\x03 \x01(\x11H\x00\x12\x12\n\narray_size\x18\x04 \x01(\x11\x42\x13\n\x11maximum_time_enum\"a\n\x17\x46\x65tchMultiPointResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x15\n\rreading_array\x18\x02 \x03(\x01\x12\x1f\n\x17\x61\x63tual_number_of_points\x18\x03 \x01(\x11\"\xae\x01\n\x14\x46\x65tchWaveformRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12-\n\x0cmaximum_time\x18\x02 \x01(\x0e\x32\x15.nidmm_grpc.TimeLimitH\x00\x12\x1a\n\x10maximum_time_raw\x18\x03 \x01(\x11H\x00\x12\x12\n\narray_size\x18\x04 \x01(\x11\x42\x13\n\x11maximum_time_enum\"`\n\x15\x46\x65tchWaveformResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x16\n\x0ewaveform_array\x18\x02 \x03(\x01\x12\x1f\n\x17\x61\x63tual_number_of_points\x18\x03 \x01(\x11\"@\n\x1aGetApertureTimeInfoRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"\xd6\x01\n\x1bGetApertureTimeInfoResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12/\n\raperture_time\x18\x02 \x01(\x0e\x32\x18.nidmm_grpc.ApertureTime\x12\x19\n\x11\x61perture_time_raw\x18\x03 \x01(\x01\x12:\n\x13\x61perture_time_units\x18\x04 \x01(\x0e\x32\x1d.nidmm_grpc.ApertureTimeUnits\x12\x1f\n\x17\x61perture_time_units_raw\x18\x05 \x01(\x11\"\x8a\x01\n\x1cGetAttributeViBooleanRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x30\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\x1a.nidmm_grpc.NiDmmAttribute\"H\n\x1dGetAttributeViBooleanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x17\n\x0f\x61ttribute_value\x18\x02 \x01(\x08\"\x88\x01\n\x1aGetAttributeViInt32Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x30\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\x1a.nidmm_grpc.NiDmmAttribute\"F\n\x1bGetAttributeViInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x17\n\x0f\x61ttribute_value\x18\x02 \x01(\x11\"\x89\x01\n\x1bGetAttributeViReal64Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x30\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\x1a.nidmm_grpc.NiDmmAttribute\"G\n\x1cGetAttributeViReal64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x17\n\x0f\x61ttribute_value\x18\x02 \x01(\x01\"\x8a\x01\n\x1cGetAttributeViSessionRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x30\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\x1a.nidmm_grpc.NiDmmAttribute\"`\n\x1dGetAttributeViSessionResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12/\n\x0f\x61ttribute_value\x18\x02 \x01(\x0b\x32\x16.nidevice_grpc.Session\"\x89\x01\n\x1bGetAttributeViStringRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x30\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\x1a.nidmm_grpc.NiDmmAttribute\"G\n\x1cGetAttributeViStringResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x17\n\x0f\x61ttribute_value\x18\x02 \x01(\t\">\n\x18GetAutoRangeValueRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"A\n\x19GetAutoRangeValueResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x14\n\x0c\x61\x63tual_range\x18\x02 \x01(\x01\"\x98\x01\n\x18GetCalDateAndTimeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12/\n\x08\x63\x61l_type\x18\x02 \x01(\x0e\x32\x1b.nidmm_grpc.CalibrationTypeH\x00\x12\x16\n\x0c\x63\x61l_type_raw\x18\x03 \x01(\x11H\x00\x42\x0f\n\rcal_type_enum\"s\n\x19GetCalDateAndTimeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05month\x18\x02 \x01(\x11\x12\x0b\n\x03\x64\x61y\x18\x03 \x01(\x11\x12\x0c\n\x04year\x18\x04 \x01(\x11\x12\x0c\n\x04hour\x18\x05 \x01(\x11\x12\x0e\n\x06minute\x18\x06 \x01(\x11\"J\n\x15GetChannelNameRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\r\n\x05index\x18\x02 \x01(\x11\"@\n\x16GetChannelNameResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x16\n\x0e\x63hannel_string\x18\x02 \x01(\t\"H\n\x11GetDevTempRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x0f\n\x07options\x18\x02 \x01(\t\"9\n\x12GetDevTempResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x13\n\x0btemperature\x18\x02 \x01(\x01\"5\n\x0fGetErrorRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"K\n\x10GetErrorResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x12\n\nerror_code\x18\x02 \x01(\x11\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\"P\n\x16GetErrorMessageRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x12\n\nerror_code\x18\x02 \x01(\x11\"@\n\x17GetErrorMessageResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x15\n\rerror_message\x18\x02 \x01(\t\"I\n#GetExtCalRecommendedIntervalRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"F\n$GetExtCalRecommendedIntervalResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0e\n\x06months\x18\x02 \x01(\x11\"\x95\x01\n\x15GetLastCalTempRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12/\n\x08\x63\x61l_type\x18\x02 \x01(\x0e\x32\x1b.nidmm_grpc.CalibrationTypeH\x00\x12\x16\n\x0c\x63\x61l_type_raw\x18\x03 \x01(\x11H\x00\x42\x0f\n\rcal_type_enum\"=\n\x16GetLastCalTempResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x13\n\x0btemperature\x18\x02 \x01(\x01\"A\n\x1bGetMeasurementPeriodRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\">\n\x1cGetMeasurementPeriodResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0e\n\x06period\x18\x02 \x01(\x01\"B\n\x1cGetNextCoercionRecordRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"H\n\x1dGetNextCoercionRecordResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x17\n\x0f\x63oercion_record\x18\x02 \x01(\t\"F\n GetNextInterchangeWarningRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"P\n!GetNextInterchangeWarningResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x1b\n\x13interchange_warning\x18\x02 \x01(\t\"@\n\x1aGetSelfCalSupportedRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"I\n\x1bGetSelfCalSupportedResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x1a\n\x12self_cal_supported\x18\x02 \x01(\x08\"f\n)ImportAttributeConfigurationBufferRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x15\n\rconfiguration\x18\x02 \x01(\x0c\"<\n*ImportAttributeConfigurationBufferResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"`\n\'ImportAttributeConfigurationFileRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x11\n\tfile_path\x18\x02 \x01(\t\":\n(ImportAttributeConfigurationFileResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xb1\x01\n\x0bInitRequest\x12\x14\n\x0csession_name\x18\x01 \x01(\t\x12\x15\n\rresource_name\x18\x02 \x01(\t\x12\x10\n\x08id_query\x18\x03 \x01(\x08\x12\x14\n\x0creset_device\x18\x04 \x01(\x08\x12M\n\x17initialization_behavior\x18\x05 \x01(\x0e\x32,.nidevice_grpc.SessionInitializationBehavior\"~\n\x0cInitResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\"\n\x02vi\x18\x02 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x19\n\rerror_message\x18\x03 \x01(\tB\x02\x18\x01\x12\x1f\n\x17new_session_initialized\x18\x04 \x01(\x08\"\xd3\x01\n\x16InitWithOptionsRequest\x12\x14\n\x0csession_name\x18\x01 \x01(\t\x12\x15\n\rresource_name\x18\x02 \x01(\t\x12\x10\n\x08id_query\x18\x03 \x01(\x08\x12\x14\n\x0creset_device\x18\x04 \x01(\x08\x12\x15\n\roption_string\x18\x05 \x01(\t\x12M\n\x17initialization_behavior\x18\x06 \x01(\x0e\x32,.nidevice_grpc.SessionInitializationBehavior\"\x89\x01\n\x17InitWithOptionsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\"\n\x02vi\x18\x02 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x19\n\rerror_message\x18\x03 \x01(\tB\x02\x18\x01\x12\x1f\n\x17new_session_initialized\x18\x04 \x01(\x08\"5\n\x0fInitiateRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"\"\n\x10InitiateResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"D\n\x1eInvalidateAllAttributesRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"1\n\x1fInvalidateAllAttributesResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"S\n\x12IsOverRangeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x19\n\x11measurement_value\x18\x02 \x01(\x01\"<\n\x13IsOverRangeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x15\n\ris_over_range\x18\x02 \x01(\x08\"T\n\x13IsUnderRangeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x19\n\x11measurement_value\x18\x02 \x01(\x01\">\n\x14IsUnderRangeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x16\n\x0eis_under_range\x18\x02 \x01(\x08\"A\n\x1bPerformOpenCableCompRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"X\n\x1cPerformOpenCableCompResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x13\n\x0b\x63onductance\x18\x02 \x01(\x01\x12\x13\n\x0bsusceptance\x18\x03 \x01(\x01\"B\n\x1cPerformShortCableCompRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"V\n\x1dPerformShortCableCompResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x12\n\nresistance\x18\x02 \x01(\x01\x12\x11\n\treactance\x18\x03 \x01(\x01\"\x91\x01\n\x0bReadRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12-\n\x0cmaximum_time\x18\x02 \x01(\x0e\x32\x15.nidmm_grpc.TimeLimitH\x00\x12\x1a\n\x10maximum_time_raw\x18\x03 \x01(\x11H\x00\x42\x13\n\x11maximum_time_enum\"/\n\x0cReadResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0f\n\x07reading\x18\x02 \x01(\x01\"\xaf\x01\n\x15ReadMultiPointRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12-\n\x0cmaximum_time\x18\x02 \x01(\x0e\x32\x15.nidmm_grpc.TimeLimitH\x00\x12\x1a\n\x10maximum_time_raw\x18\x03 \x01(\x11H\x00\x12\x12\n\narray_size\x18\x04 \x01(\x11\x42\x13\n\x11maximum_time_enum\"`\n\x16ReadMultiPointResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x15\n\rreading_array\x18\x02 \x03(\x01\x12\x1f\n\x17\x61\x63tual_number_of_points\x18\x03 \x01(\x11\"7\n\x11ReadStatusRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"\x9c\x01\n\x12ReadStatusResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x1b\n\x13\x61\x63quisition_backlog\x18\x02 \x01(\x11\x12\x39\n\x12\x61\x63quisition_status\x18\x03 \x01(\x0e\x32\x1d.nidmm_grpc.AcquisitionStatus\x12\x1e\n\x16\x61\x63quisition_status_raw\x18\x04 \x01(\x11\"\xad\x01\n\x13ReadWaveformRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12-\n\x0cmaximum_time\x18\x02 \x01(\x0e\x32\x15.nidmm_grpc.TimeLimitH\x00\x12\x1a\n\x10maximum_time_raw\x18\x03 \x01(\x11H\x00\x12\x12\n\narray_size\x18\x04 \x01(\x11\x42\x13\n\x11maximum_time_enum\"_\n\x14ReadWaveformResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x16\n\x0ewaveform_array\x18\x02 \x03(\x01\x12\x1f\n\x17\x61\x63tual_number_of_points\x18\x03 \x01(\x11\"2\n\x0cResetRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"\x1f\n\rResetResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"B\n\x1cResetInterchangeCheckRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"/\n\x1dResetInterchangeCheckResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\">\n\x18ResetWithDefaultsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"+\n\x19ResetWithDefaultsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\":\n\x14RevisionQueryRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"f\n\x15RevisionQueryResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\"\n\x1ainstrument_driver_revision\x18\x02 \x01(\t\x12\x19\n\x11\x66irmware_revision\x18\x03 \x01(\t\"4\n\x0eSelfCalRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"!\n\x0fSelfCalResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"5\n\x0fSelfTestRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"W\n\x10SelfTestResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x18\n\x10self_test_result\x18\x02 \x01(\x11\x12\x19\n\x11self_test_message\x18\x03 \x01(\t\"@\n\x1aSendSoftwareTriggerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"-\n\x1bSendSoftwareTriggerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xa3\x01\n\x1cSetAttributeViBooleanRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x30\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\x1a.nidmm_grpc.NiDmmAttribute\x12\x17\n\x0f\x61ttribute_value\x18\x04 \x01(\x08\"/\n\x1dSetAttributeViBooleanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x81\x02\n\x1aSetAttributeViInt32Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x30\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\x1a.nidmm_grpc.NiDmmAttribute\x12@\n\x0f\x61ttribute_value\x18\x04 \x01(\x0e\x32%.nidmm_grpc.NiDmmInt32AttributeValuesH\x00\x12\x1d\n\x13\x61ttribute_value_raw\x18\x05 \x01(\x11H\x00\x42\x16\n\x14\x61ttribute_value_enum\"-\n\x1bSetAttributeViInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xd3\x02\n\x1bSetAttributeViReal64Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x30\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\x1a.nidmm_grpc.NiDmmAttribute\x12\x41\n\x0f\x61ttribute_value\x18\x04 \x01(\x0e\x32&.nidmm_grpc.NiDmmReal64AttributeValuesH\x00\x12\x1d\n\x13\x61ttribute_value_raw\x18\x05 \x01(\x01H\x00\x12N\n\x16\x61ttribute_value_mapped\x18\x06 \x01(\x0e\x32,.nidmm_grpc.NiDmmReal64AttributeValuesMappedH\x00\x42\x16\n\x14\x61ttribute_value_enum\".\n\x1cSetAttributeViReal64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xbb\x01\n\x1cSetAttributeViSessionRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x30\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\x1a.nidmm_grpc.NiDmmAttribute\x12/\n\x0f\x61ttribute_value\x18\x04 \x01(\x0b\x32\x16.nidevice_grpc.Session\"/\n\x1dSetAttributeViSessionResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xa6\x01\n\x1bSetAttributeViStringRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x30\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\x1a.nidmm_grpc.NiDmmAttribute\x12\x1b\n\x13\x61ttribute_value_raw\x18\x04 \x01(\t\".\n\x1cSetAttributeViStringResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05*\x8a\x1b\n\x0eNiDmmAttribute\x12\x1f\n\x1bNIDMM_ATTRIBUTE_UNSPECIFIED\x10\x00\x12!\n\x1bNIDMM_ATTRIBUTE_RANGE_CHECK\x10\x92\x8b@\x12-\n\'NIDMM_ATTRIBUTE_QUERY_INSTRUMENT_STATUS\x10\x93\x8b@\x12\x1b\n\x15NIDMM_ATTRIBUTE_CACHE\x10\x94\x8b@\x12\x1e\n\x18NIDMM_ATTRIBUTE_SIMULATE\x10\x95\x8b@\x12&\n NIDMM_ATTRIBUTE_RECORD_COERCIONS\x10\x96\x8b@\x12\"\n\x1cNIDMM_ATTRIBUTE_DRIVER_SETUP\x10\x97\x8b@\x12\'\n!NIDMM_ATTRIBUTE_INTERCHANGE_CHECK\x10\xa5\x8b@\x12#\n\x1dNIDMM_ATTRIBUTE_CHANNEL_COUNT\x10\xdb\x8c@\x12,\n&NIDMM_ATTRIBUTE_SPECIFIC_DRIVER_PREFIX\x10\xbe\x8d@\x12,\n&NIDMM_ATTRIBUTE_IO_RESOURCE_DESCRIPTOR\x10\xc0\x8d@\x12\"\n\x1cNIDMM_ATTRIBUTE_LOGICAL_NAME\x10\xc1\x8d@\x12\x31\n+NIDMM_ATTRIBUTE_SUPPORTED_INSTRUMENT_MODELS\x10\xd7\x8d@\x12(\n\"NIDMM_ATTRIBUTE_GROUP_CAPABILITIES\x10\xa1\x8e@\x12\x33\n-NIDMM_ATTRIBUTE_SPECIFIC_DRIVER_MAJOR_VERSION\x10\x87\x8f@\x12\x33\n-NIDMM_ATTRIBUTE_SPECIFIC_DRIVER_MINOR_VERSION\x10\x88\x8f@\x12\x32\n,NIDMM_ATTRIBUTE_INSTRUMENT_FIRMWARE_REVISION\x10\x8e\x8f@\x12-\n\'NIDMM_ATTRIBUTE_INSTRUMENT_MANUFACTURER\x10\x8f\x8f@\x12&\n NIDMM_ATTRIBUTE_INSTRUMENT_MODEL\x10\x90\x8f@\x12,\n&NIDMM_ATTRIBUTE_SPECIFIC_DRIVER_VENDOR\x10\x91\x8f@\x12\x31\n+NIDMM_ATTRIBUTE_SPECIFIC_DRIVER_DESCRIPTION\x10\x92\x8f@\x12>\n8NIDMM_ATTRIBUTE_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION\x10\x93\x8f@\x12>\n8NIDMM_ATTRIBUTE_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION\x10\x94\x8f@\x12.\n(NIDMM_ATTRIBUTE_SPECIFIC_DRIVER_REVISION\x10\xb7\x8f@\x12%\n\x1fNIDMM_ATTRIBUTE_MEAS_DEST_SLOPE\x10\xb2\x98\x46\x12!\n\x1bNIDMM_ATTRIBUTE_SHUNT_VALUE\x10\xb3\x98\x46\x12*\n$NIDMM_ATTRIBUTE_SAMPLE_TRIGGER_SLOPE\x10\xba\x98\x46\x12$\n\x1eNIDMM_ATTRIBUTE_OPERATION_MODE\x10\xbe\x98\x46\x12#\n\x1dNIDMM_ATTRIBUTE_WAVEFORM_RATE\x10\xc2\x98\x46\x12%\n\x1fNIDMM_ATTRIBUTE_WAVEFORM_POINTS\x10\xc3\x98\x46\x12%\n\x1fNIDMM_ATTRIBUTE_ADC_CALIBRATION\x10\xc6\x98\x46\x12&\n NIDMM_ATTRIBUTE_OFFSET_COMP_OHMS\x10\xc7\x98\x46\x12$\n\x1eNIDMM_ATTRIBUTE_CURRENT_SOURCE\x10\xc9\x98\x46\x12(\n\"NIDMM_ATTRIBUTE_DC_NOISE_REJECTION\x10\xca\x98\x46\x12\'\n!NIDMM_ATTRIBUTE_WAVEFORM_COUPLING\x10\xcb\x98\x46\x12!\n\x1bNIDMM_ATTRIBUTE_SETTLE_TIME\x10\xcc\x98\x46\x12&\n NIDMM_ATTRIBUTE_INPUT_RESISTANCE\x10\xcd\x98\x46\x12(\n\"NIDMM_ATTRIBUTE_NUMBER_OF_AVERAGES\x10\xd0\x98\x46\x12\x1d\n\x17NIDMM_ATTRIBUTE_LATENCY\x10\xd2\x98\x46\x12!\n\x1bNIDMM_ATTRIBUTE_BUFFER_SIZE\x10\xd5\x98\x46\x12\x33\n-NIDMM_ATTRIBUTE_FREQ_VOLTAGE_AUTO_RANGE_VALUE\x10\xdc\x98\x46\x12%\n\x1fNIDMM_ATTRIBUTE_CABLE_COMP_TYPE\x10\xdd\x98\x46\x12\x30\n*NIDMM_ATTRIBUTE_SHORT_CABLE_COMP_REACTANCE\x10\xde\x98\x46\x12\x31\n+NIDMM_ATTRIBUTE_SHORT_CABLE_COMP_RESISTANCE\x10\xdf\x98\x46\x12\x31\n+NIDMM_ATTRIBUTE_OPEN_CABLE_COMP_SUSCEPTANCE\x10\xe0\x98\x46\x12\x31\n+NIDMM_ATTRIBUTE_OPEN_CABLE_COMP_CONDUCTANCE\x10\xe1\x98\x46\x12*\n$NIDMM_ATTRIBUTE_LC_CALCULATION_MODEL\x10\xe4\x98\x46\x12\x1d\n\x17NIDMM_ATTRIBUTE_DC_BIAS\x10\xe5\x98\x46\x12#\n\x1dNIDMM_ATTRIBUTE_SERIAL_NUMBER\x10\xe6\x98\x46\x12/\n)NIDMM_ATTRIBUTE_LC_NUMBER_MEAS_TO_AVERAGE\x10\xe7\x98\x46\x12+\n%NIDMM_ATTRIBUTE_CONFIG_PRODUCT_NUMBER\x10\xed\x98\x46\x12#\n\x1dNIDMM_ATTRIBUTE_TEMP_RTD_TYPE\x10\xa8\x99\x46\x12 \n\x1aNIDMM_ATTRIBUTE_TEMP_RTD_A\x10\xa9\x99\x46\x12 \n\x1aNIDMM_ATTRIBUTE_TEMP_RTD_B\x10\xaa\x99\x46\x12 \n\x1aNIDMM_ATTRIBUTE_TEMP_RTD_C\x10\xab\x99\x46\x12*\n$NIDMM_ATTRIBUTE_TEMP_THERMISTOR_TYPE\x10\xac\x99\x46\x12\'\n!NIDMM_ATTRIBUTE_TEMP_THERMISTOR_A\x10\xad\x99\x46\x12\'\n!NIDMM_ATTRIBUTE_TEMP_THERMISTOR_B\x10\xae\x99\x46\x12\'\n!NIDMM_ATTRIBUTE_TEMP_THERMISTOR_C\x10\xaf\x99\x46\x12\x1e\n\x18NIDMM_ATTRIBUTE_FUNCTION\x10\xd1\xa5L\x12\x1b\n\x15NIDMM_ATTRIBUTE_RANGE\x10\xd2\xa5L\x12\'\n!NIDMM_ATTRIBUTE_RESOLUTION_DIGITS\x10\xd3\xa5L\x12$\n\x1eNIDMM_ATTRIBUTE_TRIGGER_SOURCE\x10\xd4\xa5L\x12#\n\x1dNIDMM_ATTRIBUTE_TRIGGER_DELAY\x10\xd5\xa5L\x12!\n\x1bNIDMM_ATTRIBUTE_AC_MIN_FREQ\x10\xd6\xa5L\x12!\n\x1bNIDMM_ATTRIBUTE_AC_MAX_FREQ\x10\xd7\xa5L\x12)\n#NIDMM_ATTRIBUTE_RESOLUTION_ABSOLUTE\x10\xd8\xa5L\x12(\n\"NIDMM_ATTRIBUTE_FREQ_VOLTAGE_RANGE\x10\xb5\xa6L\x12*\n$NIDMM_ATTRIBUTE_TEMP_TRANSDUCER_TYPE\x10\x99\xa7L\x12\"\n\x1cNIDMM_ATTRIBUTE_TEMP_TC_TYPE\x10\xb7\xa7L\x12+\n%NIDMM_ATTRIBUTE_TEMP_TC_REF_JUNC_TYPE\x10\xb8\xa7L\x12,\n&NIDMM_ATTRIBUTE_TEMP_TC_FIXED_REF_JUNC\x10\xb9\xa7L\x12\"\n\x1cNIDMM_ATTRIBUTE_TEMP_RTD_RES\x10\xc2\xa7L\x12\"\n\x1cNIDMM_ATTRIBUTE_SAMPLE_COUNT\x10\xfd\xa7L\x12$\n\x1eNIDMM_ATTRIBUTE_SAMPLE_TRIGGER\x10\xfe\xa7L\x12%\n\x1fNIDMM_ATTRIBUTE_SAMPLE_INTERVAL\x10\xff\xa7L\x12#\n\x1dNIDMM_ATTRIBUTE_TRIGGER_COUNT\x10\x80\xa8L\x12(\n\"NIDMM_ATTRIBUTE_MEAS_COMPLETE_DEST\x10\x81\xa8L\x12#\n\x1dNIDMM_ATTRIBUTE_APERTURE_TIME\x10\x91\xa8L\x12)\n#NIDMM_ATTRIBUTE_APERTURE_TIME_UNITS\x10\x92\xa8L\x12&\n NIDMM_ATTRIBUTE_AUTO_RANGE_VALUE\x10\x9b\xa8L\x12\x1f\n\x19NIDMM_ATTRIBUTE_AUTO_ZERO\x10\x9c\xa8L\x12$\n\x1eNIDMM_ATTRIBUTE_POWERLINE_FREQ\x10\x9d\xa8L\x12#\n\x1dNIDMM_ATTRIBUTE_TRIGGER_SLOPE\x10\x9e\xa8L*\xa4\x02\n\x11\x41\x63quisitionStatus\x12\x36\n2ACQUISITION_STATUS_NIDMM_VAL_RUNNING_ANTICOLLISION\x10\x00\x12\x36\n2ACQUISITION_STATUS_NIDMM_VAL_FINISHED_WITH_BACKLOG\x10\x01\x12\x39\n5ACQUISITION_STATUS_NIDMM_VAL_FINISHED_WITH_NO_BACKLOG\x10\x02\x12\'\n#ACQUISITION_STATUS_NIDMM_VAL_PAUSED\x10\x03\x12;\n7ACQUISITION_STATUS_NIDMM_VAL_NO_ACQUISITION_IN_PROGRESS\x10\x04*\xe1\x02\n\x0c\x41pertureTime\x12\x1d\n\x19\x41PERTURE_TIME_UNSPECIFIED\x10\x00\x12\x37\n*APERTURE_TIME_NIDMM_VAL_APERTURE_TIME_AUTO\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12!\n\x1d\x41PERTURE_TIME_NIDMM_VAL_1_PLC\x10\x01\x12!\n\x1d\x41PERTURE_TIME_NIDMM_VAL_5_PLC\x10\x05\x12!\n\x1d\x41PERTURE_TIME_NIDMM_VAL_6_PLC\x10\x06\x12\"\n\x1e\x41PERTURE_TIME_NIDMM_VAL_10_PLC\x10\n\x12\"\n\x1e\x41PERTURE_TIME_NIDMM_VAL_12_PLC\x10\x0c\x12#\n\x1f\x41PERTURE_TIME_NIDMM_VAL_100_PLC\x10\x64\x12#\n\x1f\x41PERTURE_TIME_NIDMM_VAL_120_PLC\x10x*s\n\x11\x41pertureTimeUnits\x12)\n%APERTURE_TIME_UNITS_NIDMM_VAL_SECONDS\x10\x00\x12\x33\n/APERTURE_TIME_UNITS_NIDMM_VAL_POWER_LINE_CYCLES\x10\x01*m\n\x0f\x43\x61librationType\x12,\n(CALIBRATION_TYPE_NIDMM_VAL_INTERNAL_AREA\x10\x00\x12,\n(CALIBRATION_TYPE_NIDMM_VAL_EXTERNAL_AREA\x10\x01*z\n\x0f\x43ompensatedOhms\x12\x33\n/COMPENSATED_OHMS_NIDMM_VAL_OFFSET_COMP_OHMS_OFF\x10\x00\x12\x32\n.COMPENSATED_OHMS_NIDMM_VAL_OFFSET_COMP_OHMS_ON\x10\x01*<\n\rControlCommit\x12+\n\'CONTROL_COMMIT_NIDMM_VAL_CONTROL_COMMIT\x10\x00*\xbd\x01\n\x15\x46requencyVoltageRange\x12\'\n#FREQUENCY_VOLTAGE_RANGE_UNSPECIFIED\x10\x00\x12<\n/FREQUENCY_VOLTAGE_RANGE_NIDMM_VAL_AUTO_RANGE_ON\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12=\n0FREQUENCY_VOLTAGE_RANGE_NIDMM_VAL_AUTO_RANGE_OFF\x10\xfe\xff\xff\xff\xff\xff\xff\xff\xff\x01*\xbb\x04\n\x08\x46unction\x12\x18\n\x14\x46UNCTION_UNSPECIFIED\x10\x00\x12\x1f\n\x1b\x46UNCTION_NIDMM_VAL_DC_VOLTS\x10\x01\x12\x1f\n\x1b\x46UNCTION_NIDMM_VAL_AC_VOLTS\x10\x02\x12!\n\x1d\x46UNCTION_NIDMM_VAL_DC_CURRENT\x10\x03\x12!\n\x1d\x46UNCTION_NIDMM_VAL_AC_CURRENT\x10\x04\x12!\n\x1d\x46UNCTION_NIDMM_VAL_2_WIRE_RES\x10\x05\x12!\n\x1d\x46UNCTION_NIDMM_VAL_4_WIRE_RES\x10\x65\x12\x1b\n\x17\x46UNCTION_NIDMM_VAL_FREQ\x10h\x12\x1d\n\x19\x46UNCTION_NIDMM_VAL_PERIOD\x10i\x12\"\n\x1e\x46UNCTION_NIDMM_VAL_TEMPERATURE\x10l\x12+\n&FUNCTION_NIDMM_VAL_AC_VOLTS_DC_COUPLED\x10\xe9\x07\x12\x1d\n\x18\x46UNCTION_NIDMM_VAL_DIODE\x10\xea\x07\x12(\n#FUNCTION_NIDMM_VAL_WAVEFORM_VOLTAGE\x10\xeb\x07\x12(\n#FUNCTION_NIDMM_VAL_WAVEFORM_CURRENT\x10\xec\x07\x12#\n\x1e\x46UNCTION_NIDMM_VAL_CAPACITANCE\x10\xed\x07\x12\"\n\x1d\x46UNCTION_NIDMM_VAL_INDUCTANCE\x10\xee\x07*\xd2.\n\x19NiDmmInt32AttributeValues\x12\x1b\n\x17NIDMM_INT32_UNSPECIFIED\x10\x00\x12\x37\n3NIDMM_INT32_ADC_CALIBRATION_VAL_ADC_CALIBRATION_OFF\x10\x00\x12\x41\n4NIDMM_INT32_ADC_CALIBRATION_VAL_ADC_CALIBRATION_AUTO\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x36\n2NIDMM_INT32_ADC_CALIBRATION_VAL_ADC_CALIBRATION_ON\x10\x01\x12/\n+NIDMM_INT32_APERTURE_TIME_UNITS_VAL_SECONDS\x10\x00\x12\x39\n5NIDMM_INT32_APERTURE_TIME_UNITS_VAL_POWER_LINE_CYCLES\x10\x01\x12+\n\'NIDMM_INT32_AUTO_ZERO_VAL_AUTO_ZERO_OFF\x10\x00\x12\x35\n(NIDMM_INT32_AUTO_ZERO_VAL_AUTO_ZERO_AUTO\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12*\n&NIDMM_INT32_AUTO_ZERO_VAL_AUTO_ZERO_ON\x10\x01\x12,\n(NIDMM_INT32_AUTO_ZERO_VAL_AUTO_ZERO_ONCE\x10\x02\x12\x39\n,NIDMM_INT32_BUFFER_SIZE_VAL_BUFFER_SIZE_AUTO\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12;\n7NIDMM_INT32_CABLE_COMPENSATION_TYPE_VAL_CABLE_COMP_NONE\x10\x00\x12;\n7NIDMM_INT32_CABLE_COMPENSATION_TYPE_VAL_CABLE_COMP_OPEN\x10\x01\x12<\n8NIDMM_INT32_CABLE_COMPENSATION_TYPE_VAL_CABLE_COMP_SHORT\x10\x02\x12\x45\nANIDMM_INT32_CABLE_COMPENSATION_TYPE_VAL_CABLE_COMP_OPEN_AND_SHORT\x10\x03\x12\x39\n5NIDMM_INT32_COMPENSATED_OHMS_VAL_OFFSET_COMP_OHMS_OFF\x10\x00\x12\x38\n4NIDMM_INT32_COMPENSATED_OHMS_VAL_OFFSET_COMP_OHMS_ON\x10\x01\x12\'\n#NIDMM_INT32_DC_BIAS_VAL_DC_BIAS_OFF\x10\x00\x12&\n\"NIDMM_INT32_DC_BIAS_VAL_DC_BIAS_ON\x10\x01\x12\x32\n.NIDMM_INT32_DC_NOISE_REJECTION_VAL_DCNR_NORMAL\x10\x00\x12\x39\n,NIDMM_INT32_DC_NOISE_REJECTION_VAL_DCNR_AUTO\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x38\n4NIDMM_INT32_DC_NOISE_REJECTION_VAL_DCNR_SECOND_ORDER\x10\x01\x12\x36\n2NIDMM_INT32_DC_NOISE_REJECTION_VAL_DCNR_HIGH_ORDER\x10\x02\x12%\n!NIDMM_INT32_FUNCTION_VAL_DC_VOLTS\x10\x01\x12%\n!NIDMM_INT32_FUNCTION_VAL_AC_VOLTS\x10\x02\x12\'\n#NIDMM_INT32_FUNCTION_VAL_DC_CURRENT\x10\x03\x12\'\n#NIDMM_INT32_FUNCTION_VAL_AC_CURRENT\x10\x04\x12\'\n#NIDMM_INT32_FUNCTION_VAL_2_WIRE_RES\x10\x05\x12\'\n#NIDMM_INT32_FUNCTION_VAL_4_WIRE_RES\x10\x65\x12!\n\x1dNIDMM_INT32_FUNCTION_VAL_FREQ\x10h\x12#\n\x1fNIDMM_INT32_FUNCTION_VAL_PERIOD\x10i\x12(\n$NIDMM_INT32_FUNCTION_VAL_TEMPERATURE\x10l\x12\x31\n,NIDMM_INT32_FUNCTION_VAL_AC_VOLTS_DC_COUPLED\x10\xe9\x07\x12#\n\x1eNIDMM_INT32_FUNCTION_VAL_DIODE\x10\xea\x07\x12.\n)NIDMM_INT32_FUNCTION_VAL_WAVEFORM_VOLTAGE\x10\xeb\x07\x12.\n)NIDMM_INT32_FUNCTION_VAL_WAVEFORM_CURRENT\x10\xec\x07\x12)\n$NIDMM_INT32_FUNCTION_VAL_CAPACITANCE\x10\xed\x07\x12(\n#NIDMM_INT32_FUNCTION_VAL_INDUCTANCE\x10\xee\x07\x12\x31\n$NIDMM_INT32_LATENCY_VAL_LATENCY_AUTO\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12:\n6NIDMM_INT32_LC_CALCULATION_MODEL_VAL_CALC_MODEL_SERIES\x10\x00\x12\x41\n4NIDMM_INT32_LC_CALCULATION_MODEL_VAL_CALC_MODEL_AUTO\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12<\n8NIDMM_INT32_LC_CALCULATION_MODEL_VAL_CALC_MODEL_PARALLEL\x10\x01\x12;\n.NIDMM_INT32_MEASUREMENT_COMPLETE_DEST_VAL_NONE\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x36\n2NIDMM_INT32_MEASUREMENT_COMPLETE_DEST_VAL_EXTERNAL\x10\x02\x12\x37\n3NIDMM_INT32_MEASUREMENT_COMPLETE_DEST_VAL_PXI_TRIG0\x10o\x12\x37\n3NIDMM_INT32_MEASUREMENT_COMPLETE_DEST_VAL_PXI_TRIG1\x10p\x12\x37\n3NIDMM_INT32_MEASUREMENT_COMPLETE_DEST_VAL_PXI_TRIG2\x10q\x12\x37\n3NIDMM_INT32_MEASUREMENT_COMPLETE_DEST_VAL_PXI_TRIG3\x10r\x12\x37\n3NIDMM_INT32_MEASUREMENT_COMPLETE_DEST_VAL_PXI_TRIG4\x10s\x12\x37\n3NIDMM_INT32_MEASUREMENT_COMPLETE_DEST_VAL_PXI_TRIG5\x10t\x12\x37\n3NIDMM_INT32_MEASUREMENT_COMPLETE_DEST_VAL_PXI_TRIG6\x10u\x12\x37\n3NIDMM_INT32_MEASUREMENT_COMPLETE_DEST_VAL_PXI_TRIG7\x10v\x12\x38\n3NIDMM_INT32_MEASUREMENT_COMPLETE_DEST_VAL_LBR_TRIG0\x10\xeb\x07\x12:\n6NIDMM_INT32_MEASUREMENT_DESTINATION_SLOPE_VAL_POSITIVE\x10\x00\x12:\n6NIDMM_INT32_MEASUREMENT_DESTINATION_SLOPE_VAL_NEGATIVE\x10\x01\x12.\n*NIDMM_INT32_OPERATION_MODE_VAL_IVIDMM_MODE\x10\x00\x12\x30\n,NIDMM_INT32_OPERATION_MODE_VAL_WAVEFORM_MODE\x10\x01\x12,\n(NIDMM_INT32_RTD_TYPE_VAL_TEMP_RTD_CUSTOM\x10\x00\x12,\n(NIDMM_INT32_RTD_TYPE_VAL_TEMP_RTD_PT3750\x10\x01\x12,\n(NIDMM_INT32_RTD_TYPE_VAL_TEMP_RTD_PT3851\x10\x02\x12,\n(NIDMM_INT32_RTD_TYPE_VAL_TEMP_RTD_PT3911\x10\x03\x12,\n(NIDMM_INT32_RTD_TYPE_VAL_TEMP_RTD_PT3916\x10\x04\x12,\n(NIDMM_INT32_RTD_TYPE_VAL_TEMP_RTD_PT3920\x10\x05\x12,\n(NIDMM_INT32_RTD_TYPE_VAL_TEMP_RTD_PT3928\x10\x06\x12\x36\n2NIDMM_INT32_SAMPLE_COUNT_VAL_SAMPLE_COUNT_INFINITE\x10\x00\x12.\n*NIDMM_INT32_SAMPLE_TRIG_SLOPE_VAL_POSITIVE\x10\x00\x12.\n*NIDMM_INT32_SAMPLE_TRIG_SLOPE_VAL_NEGATIVE\x10\x01\x12,\n(NIDMM_INT32_SAMPLE_TRIGGER_VAL_IMMEDIATE\x10\x01\x12+\n\'NIDMM_INT32_SAMPLE_TRIGGER_VAL_EXTERNAL\x10\x02\x12\x30\n,NIDMM_INT32_SAMPLE_TRIGGER_VAL_SOFTWARE_TRIG\x10\x03\x12+\n\'NIDMM_INT32_SAMPLE_TRIGGER_VAL_INTERVAL\x10\n\x12,\n(NIDMM_INT32_SAMPLE_TRIGGER_VAL_PXI_TRIG0\x10o\x12,\n(NIDMM_INT32_SAMPLE_TRIGGER_VAL_PXI_TRIG1\x10p\x12,\n(NIDMM_INT32_SAMPLE_TRIGGER_VAL_PXI_TRIG2\x10q\x12,\n(NIDMM_INT32_SAMPLE_TRIGGER_VAL_PXI_TRIG3\x10r\x12,\n(NIDMM_INT32_SAMPLE_TRIGGER_VAL_PXI_TRIG4\x10s\x12,\n(NIDMM_INT32_SAMPLE_TRIGGER_VAL_PXI_TRIG5\x10t\x12,\n(NIDMM_INT32_SAMPLE_TRIGGER_VAL_PXI_TRIG6\x10u\x12,\n(NIDMM_INT32_SAMPLE_TRIGGER_VAL_PXI_TRIG7\x10v\x12,\n\'NIDMM_INT32_SAMPLE_TRIGGER_VAL_PXI_STAR\x10\x83\x01\x12-\n(NIDMM_INT32_SAMPLE_TRIGGER_VAL_AUX_TRIG1\x10\xe9\x07\x12-\n(NIDMM_INT32_SAMPLE_TRIGGER_VAL_LBR_TRIG1\x10\xec\x07\x12:\n6NIDMM_INT32_THERMISTOR_TYPE_VAL_TEMP_THERMISTOR_CUSTOM\x10\x00\x12\x39\n5NIDMM_INT32_THERMISTOR_TYPE_VAL_TEMP_THERMISTOR_44004\x10\x01\x12\x39\n5NIDMM_INT32_THERMISTOR_TYPE_VAL_TEMP_THERMISTOR_44006\x10\x02\x12\x39\n5NIDMM_INT32_THERMISTOR_TYPE_VAL_TEMP_THERMISTOR_44007\x10\x03\x12L\nHNIDMM_INT32_THERMOCOUPLE_REFERENCE_JUNCTION_TYPE_VAL_TEMP_REF_JUNC_FIXED\x10\x02\x12/\n+NIDMM_INT32_THERMOCOUPLE_TYPE_VAL_TEMP_TC_B\x10\x01\x12/\n+NIDMM_INT32_THERMOCOUPLE_TYPE_VAL_TEMP_TC_E\x10\x04\x12/\n+NIDMM_INT32_THERMOCOUPLE_TYPE_VAL_TEMP_TC_J\x10\x06\x12/\n+NIDMM_INT32_THERMOCOUPLE_TYPE_VAL_TEMP_TC_K\x10\x07\x12/\n+NIDMM_INT32_THERMOCOUPLE_TYPE_VAL_TEMP_TC_N\x10\x08\x12/\n+NIDMM_INT32_THERMOCOUPLE_TYPE_VAL_TEMP_TC_R\x10\t\x12/\n+NIDMM_INT32_THERMOCOUPLE_TYPE_VAL_TEMP_TC_S\x10\n\x12/\n+NIDMM_INT32_THERMOCOUPLE_TYPE_VAL_TEMP_TC_T\x10\x0b\x12\x30\n,NIDMM_INT32_TRANSDUCER_TYPE_VAL_THERMOCOUPLE\x10\x01\x12.\n*NIDMM_INT32_TRANSDUCER_TYPE_VAL_THERMISTOR\x10\x02\x12.\n*NIDMM_INT32_TRANSDUCER_TYPE_VAL_2_WIRE_RTD\x10\x03\x12.\n*NIDMM_INT32_TRANSDUCER_TYPE_VAL_4_WIRE_RTD\x10\x04\x12\x35\n1NIDMM_INT32_TRIGGER_COUNT_VAL_TRIG_COUNT_INFINITE\x10\x00\x12*\n&NIDMM_INT32_TRIGGER_SLOPE_VAL_POSITIVE\x10\x00\x12*\n&NIDMM_INT32_TRIGGER_SLOPE_VAL_NEGATIVE\x10\x01\x12,\n(NIDMM_INT32_TRIGGER_SOURCE_VAL_IMMEDIATE\x10\x01\x12+\n\'NIDMM_INT32_TRIGGER_SOURCE_VAL_EXTERNAL\x10\x02\x12\x30\n,NIDMM_INT32_TRIGGER_SOURCE_VAL_SOFTWARE_TRIG\x10\x03\x12,\n(NIDMM_INT32_TRIGGER_SOURCE_VAL_PXI_TRIG0\x10o\x12,\n(NIDMM_INT32_TRIGGER_SOURCE_VAL_PXI_TRIG1\x10p\x12,\n(NIDMM_INT32_TRIGGER_SOURCE_VAL_PXI_TRIG2\x10q\x12,\n(NIDMM_INT32_TRIGGER_SOURCE_VAL_PXI_TRIG3\x10r\x12,\n(NIDMM_INT32_TRIGGER_SOURCE_VAL_PXI_TRIG4\x10s\x12,\n(NIDMM_INT32_TRIGGER_SOURCE_VAL_PXI_TRIG5\x10t\x12,\n(NIDMM_INT32_TRIGGER_SOURCE_VAL_PXI_TRIG6\x10u\x12,\n(NIDMM_INT32_TRIGGER_SOURCE_VAL_PXI_TRIG7\x10v\x12,\n\'NIDMM_INT32_TRIGGER_SOURCE_VAL_PXI_STAR\x10\x83\x01\x12-\n(NIDMM_INT32_TRIGGER_SOURCE_VAL_AUX_TRIG1\x10\xe9\x07\x12-\n(NIDMM_INT32_TRIGGER_SOURCE_VAL_LBR_TRIG1\x10\xec\x07\x12:\n6NIDMM_INT32_WAVEFORM_COUPLING_VAL_WAVEFORM_COUPLING_AC\x10\x00\x12:\n6NIDMM_INT32_WAVEFORM_COUPLING_VAL_WAVEFORM_COUPLING_DC\x10\x01\x1a\x02\x10\x01*\xac\x08\n\x1aNiDmmReal64AttributeValues\x12\x1c\n\x18NIDMM_REAL64_UNSPECIFIED\x10\x00\x12>\n1NIDMM_REAL64_APERTURE_TIME_VAL_APERTURE_TIME_AUTO\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12(\n$NIDMM_REAL64_APERTURE_TIME_VAL_1_PLC\x10\x01\x12(\n$NIDMM_REAL64_APERTURE_TIME_VAL_5_PLC\x10\x05\x12(\n$NIDMM_REAL64_APERTURE_TIME_VAL_6_PLC\x10\x06\x12)\n%NIDMM_REAL64_APERTURE_TIME_VAL_10_PLC\x10\n\x12)\n%NIDMM_REAL64_APERTURE_TIME_VAL_12_PLC\x10\x0c\x12*\n&NIDMM_REAL64_APERTURE_TIME_VAL_100_PLC\x10\x64\x12*\n&NIDMM_REAL64_APERTURE_TIME_VAL_120_PLC\x10x\x12\x43\n6NIDMM_REAL64_FREQUENCY_VOLTAGE_RANGE_VAL_AUTO_RANGE_ON\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x44\n7NIDMM_REAL64_FREQUENCY_VOLTAGE_RANGE_VAL_AUTO_RANGE_OFF\x10\xfe\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x34\n0NIDMM_REAL64_POWER_LINE_FREQUENCIES_VAL_50_HERTZ\x10\x32\x12\x34\n0NIDMM_REAL64_POWER_LINE_FREQUENCIES_VAL_60_HERTZ\x10<\x12\x31\n$NIDMM_REAL64_RANGE_VAL_AUTO_RANGE_ON\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x32\n%NIDMM_REAL64_RANGE_VAL_AUTO_RANGE_OFF\x10\xfe\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x33\n&NIDMM_REAL64_RANGE_VAL_AUTO_RANGE_ONCE\x10\xfd\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x38\n+NIDMM_REAL64_SAMPLE_INTERVAL_VAL_AUTO_DELAY\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12:\n-NIDMM_REAL64_SETTLE_TIME_VAL_SETTLE_TIME_AUTO\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12:\n-NIDMM_REAL64_TRIGGER_DELAYS_VAL_AUTO_DELAY_ON\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12;\n.NIDMM_REAL64_TRIGGER_DELAYS_VAL_AUTO_DELAY_OFF\x10\xfe\xff\xff\xff\xff\xff\xff\xff\xff\x01\x1a\x02\x10\x01*\xac\x03\n NiDmmReal64AttributeValuesMapped\x12#\n\x1fNIDMM_REAL64_MAPPED_UNSPECIFIED\x10\x00\x12.\n*NIDMM_REAL64_CURRENT_SOURCE_VAL_1_MICROAMP\x10\x01\x12/\n+NIDMM_REAL64_CURRENT_SOURCE_VAL_10_MICROAMP\x10\x02\x12\x30\n,NIDMM_REAL64_CURRENT_SOURCE_VAL_100_MICROAMP\x10\x03\x12.\n*NIDMM_REAL64_CURRENT_SOURCE_VAL_1_MILLIAMP\x10\x04\x12/\n+NIDMM_REAL64_INPUT_RESISTANCE_VAL_1_MEGAOHM\x10\x05\x12\x30\n,NIDMM_REAL64_INPUT_RESISTANCE_VAL_10_MEGAOHM\x10\x06\x12=\n9NIDMM_REAL64_INPUT_RESISTANCE_VAL_GREATER_THAN_10_GIGAOHM\x10\x07*\x9c\x01\n\x14PowerLineFrequencies\x12&\n\"POWER_LINE_FREQUENCIES_UNSPECIFIED\x10\x00\x12-\n)POWER_LINE_FREQUENCIES_NIDMM_VAL_50_HERTZ\x10\x32\x12-\n)POWER_LINE_FREQUENCIES_NIDMM_VAL_60_HERTZ\x10<*\xa1\x02\n\x07RtdType\x12&\n\"RTD_TYPE_NIDMM_VAL_TEMP_RTD_CUSTOM\x10\x00\x12&\n\"RTD_TYPE_NIDMM_VAL_TEMP_RTD_PT3750\x10\x01\x12&\n\"RTD_TYPE_NIDMM_VAL_TEMP_RTD_PT3851\x10\x02\x12&\n\"RTD_TYPE_NIDMM_VAL_TEMP_RTD_PT3911\x10\x03\x12&\n\"RTD_TYPE_NIDMM_VAL_TEMP_RTD_PT3916\x10\x04\x12&\n\"RTD_TYPE_NIDMM_VAL_TEMP_RTD_PT3920\x10\x05\x12&\n\"RTD_TYPE_NIDMM_VAL_TEMP_RTD_PT3928\x10\x06*?\n\x0bSampleCount\x12\x30\n,SAMPLE_COUNT_NIDMM_VAL_SAMPLE_COUNT_INFINITE\x10\x00*d\n\x0eSampleInterval\x12\x1f\n\x1bSAMPLE_INTERVAL_UNSPECIFIED\x10\x00\x12\x31\n$SAMPLE_INTERVAL_NIDMM_VAL_AUTO_DELAY\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01*e\n\x0fSampleTrigSlope\x12(\n$SAMPLE_TRIG_SLOPE_NIDMM_VAL_POSITIVE\x10\x00\x12(\n$SAMPLE_TRIG_SLOPE_NIDMM_VAL_NEGATIVE\x10\x01*\x8b\x05\n\rSampleTrigger\x12\x1e\n\x1aSAMPLE_TRIGGER_UNSPECIFIED\x10\x00\x12&\n\"SAMPLE_TRIGGER_NIDMM_VAL_IMMEDIATE\x10\x01\x12%\n!SAMPLE_TRIGGER_NIDMM_VAL_EXTERNAL\x10\x02\x12*\n&SAMPLE_TRIGGER_NIDMM_VAL_SOFTWARE_TRIG\x10\x03\x12%\n!SAMPLE_TRIGGER_NIDMM_VAL_INTERVAL\x10\n\x12&\n\"SAMPLE_TRIGGER_NIDMM_VAL_PXI_TRIG0\x10o\x12&\n\"SAMPLE_TRIGGER_NIDMM_VAL_PXI_TRIG1\x10p\x12&\n\"SAMPLE_TRIGGER_NIDMM_VAL_PXI_TRIG2\x10q\x12&\n\"SAMPLE_TRIGGER_NIDMM_VAL_PXI_TRIG3\x10r\x12&\n\"SAMPLE_TRIGGER_NIDMM_VAL_PXI_TRIG4\x10s\x12&\n\"SAMPLE_TRIGGER_NIDMM_VAL_PXI_TRIG5\x10t\x12&\n\"SAMPLE_TRIGGER_NIDMM_VAL_PXI_TRIG6\x10u\x12&\n\"SAMPLE_TRIGGER_NIDMM_VAL_PXI_TRIG7\x10v\x12&\n!SAMPLE_TRIGGER_NIDMM_VAL_PXI_STAR\x10\x83\x01\x12\'\n\"SAMPLE_TRIGGER_NIDMM_VAL_AUX_TRIG1\x10\xe9\x07\x12\'\n\"SAMPLE_TRIGGER_NIDMM_VAL_LBR_TRIG1\x10\xec\x07*\xa1\x01\n!ThermocoupleReferenceJunctionType\x12\x34\n0THERMOCOUPLE_REFERENCE_JUNCTION_TYPE_UNSPECIFIED\x10\x00\x12\x46\nBTHERMOCOUPLE_REFERENCE_JUNCTION_TYPE_NIDMM_VAL_TEMP_REF_JUNC_FIXED\x10\x02*\x8d\x03\n\x10ThermocoupleType\x12!\n\x1dTHERMOCOUPLE_TYPE_UNSPECIFIED\x10\x00\x12)\n%THERMOCOUPLE_TYPE_NIDMM_VAL_TEMP_TC_B\x10\x01\x12)\n%THERMOCOUPLE_TYPE_NIDMM_VAL_TEMP_TC_E\x10\x04\x12)\n%THERMOCOUPLE_TYPE_NIDMM_VAL_TEMP_TC_J\x10\x06\x12)\n%THERMOCOUPLE_TYPE_NIDMM_VAL_TEMP_TC_K\x10\x07\x12)\n%THERMOCOUPLE_TYPE_NIDMM_VAL_TEMP_TC_N\x10\x08\x12)\n%THERMOCOUPLE_TYPE_NIDMM_VAL_TEMP_TC_R\x10\t\x12)\n%THERMOCOUPLE_TYPE_NIDMM_VAL_TEMP_TC_S\x10\n\x12)\n%THERMOCOUPLE_TYPE_NIDMM_VAL_TEMP_TC_T\x10\x0b*Z\n\tTimeLimit\x12\x1a\n\x16TIME_LIMIT_UNSPECIFIED\x10\x00\x12\x31\n$TIME_LIMIT_NIDMM_VAL_TIME_LIMIT_AUTO\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01*?\n\x0cTriggerCount\x12/\n+TRIGGER_COUNT_NIDMM_VAL_TRIG_COUNT_INFINITE\x10\x00*\x9a\x01\n\rTriggerDelays\x12\x1e\n\x1aTRIGGER_DELAYS_UNSPECIFIED\x10\x00\x12\x33\n&TRIGGER_DELAYS_NIDMM_VAL_AUTO_DELAY_ON\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x34\n\'TRIGGER_DELAYS_NIDMM_VAL_AUTO_DELAY_OFF\x10\xfe\xff\xff\xff\xff\xff\xff\xff\xff\x01*Z\n\x0cTriggerSlope\x12$\n TRIGGER_SLOPE_NIDMM_VAL_POSITIVE\x10\x00\x12$\n TRIGGER_SLOPE_NIDMM_VAL_NEGATIVE\x10\x01*\xe4\x04\n\rTriggerSource\x12\x1e\n\x1aTRIGGER_SOURCE_UNSPECIFIED\x10\x00\x12&\n\"TRIGGER_SOURCE_NIDMM_VAL_IMMEDIATE\x10\x01\x12%\n!TRIGGER_SOURCE_NIDMM_VAL_EXTERNAL\x10\x02\x12*\n&TRIGGER_SOURCE_NIDMM_VAL_SOFTWARE_TRIG\x10\x03\x12&\n\"TRIGGER_SOURCE_NIDMM_VAL_PXI_TRIG0\x10o\x12&\n\"TRIGGER_SOURCE_NIDMM_VAL_PXI_TRIG1\x10p\x12&\n\"TRIGGER_SOURCE_NIDMM_VAL_PXI_TRIG2\x10q\x12&\n\"TRIGGER_SOURCE_NIDMM_VAL_PXI_TRIG3\x10r\x12&\n\"TRIGGER_SOURCE_NIDMM_VAL_PXI_TRIG4\x10s\x12&\n\"TRIGGER_SOURCE_NIDMM_VAL_PXI_TRIG5\x10t\x12&\n\"TRIGGER_SOURCE_NIDMM_VAL_PXI_TRIG6\x10u\x12&\n\"TRIGGER_SOURCE_NIDMM_VAL_PXI_TRIG7\x10v\x12&\n!TRIGGER_SOURCE_NIDMM_VAL_PXI_STAR\x10\x83\x01\x12\'\n\"TRIGGER_SOURCE_NIDMM_VAL_AUX_TRIG1\x10\xe9\x07\x12\'\n\"TRIGGER_SOURCE_NIDMM_VAL_LBR_TRIG1\x10\xec\x07\x32\xce\x46\n\x05NiDmm\x12<\n\x05\x41\x62ort\x12\x18.nidmm_grpc.AbortRequest\x1a\x19.nidmm_grpc.AbortResponse\x12r\n\x17\x43heckAttributeViBoolean\x12*.nidmm_grpc.CheckAttributeViBooleanRequest\x1a+.nidmm_grpc.CheckAttributeViBooleanResponse\x12l\n\x15\x43heckAttributeViInt32\x12(.nidmm_grpc.CheckAttributeViInt32Request\x1a).nidmm_grpc.CheckAttributeViInt32Response\x12o\n\x16\x43heckAttributeViReal64\x12).nidmm_grpc.CheckAttributeViReal64Request\x1a*.nidmm_grpc.CheckAttributeViReal64Response\x12r\n\x17\x43heckAttributeViSession\x12*.nidmm_grpc.CheckAttributeViSessionRequest\x1a+.nidmm_grpc.CheckAttributeViSessionResponse\x12o\n\x16\x43heckAttributeViString\x12).nidmm_grpc.CheckAttributeViStringRequest\x1a*.nidmm_grpc.CheckAttributeViStringResponse\x12K\n\nClearError\x12\x1d.nidmm_grpc.ClearErrorRequest\x1a\x1e.nidmm_grpc.ClearErrorResponse\x12u\n\x18\x43learInterchangeWarnings\x12+.nidmm_grpc.ClearInterchangeWarningsRequest\x1a,.nidmm_grpc.ClearInterchangeWarningsResponse\x12<\n\x05\x43lose\x12\x18.nidmm_grpc.CloseRequest\x1a\x19.nidmm_grpc.CloseResponse\x12i\n\x14\x43onfigureACBandwidth\x12\'.nidmm_grpc.ConfigureACBandwidthRequest\x1a(.nidmm_grpc.ConfigureACBandwidthResponse\x12r\n\x17\x43onfigureADCCalibration\x12*.nidmm_grpc.ConfigureADCCalibrationRequest\x1a+.nidmm_grpc.ConfigureADCCalibrationResponse\x12l\n\x15\x43onfigureAutoZeroMode\x12(.nidmm_grpc.ConfigureAutoZeroModeRequest\x1a).nidmm_grpc.ConfigureAutoZeroModeResponse\x12o\n\x16\x43onfigureCableCompType\x12).nidmm_grpc.ConfigureCableCompTypeRequest\x1a*.nidmm_grpc.ConfigureCableCompTypeResponse\x12o\n\x16\x43onfigureCurrentSource\x12).nidmm_grpc.ConfigureCurrentSourceRequest\x1a*.nidmm_grpc.ConfigureCurrentSourceResponse\x12x\n\x19\x43onfigureFixedRefJunction\x12,.nidmm_grpc.ConfigureFixedRefJunctionRequest\x1a-.nidmm_grpc.ConfigureFixedRefJunctionResponse\x12\x87\x01\n\x1e\x43onfigureFrequencyVoltageRange\x12\x31.nidmm_grpc.ConfigureFrequencyVoltageRangeRequest\x1a\x32.nidmm_grpc.ConfigureFrequencyVoltageRangeResponse\x12x\n\x19\x43onfigureMeasCompleteDest\x12,.nidmm_grpc.ConfigureMeasCompleteDestRequest\x1a-.nidmm_grpc.ConfigureMeasCompleteDestResponse\x12{\n\x1a\x43onfigureMeasCompleteSlope\x12-.nidmm_grpc.ConfigureMeasCompleteSlopeRequest\x1a..nidmm_grpc.ConfigureMeasCompleteSlopeResponse\x12\x81\x01\n\x1c\x43onfigureMeasurementAbsolute\x12/.nidmm_grpc.ConfigureMeasurementAbsoluteRequest\x1a\x30.nidmm_grpc.ConfigureMeasurementAbsoluteResponse\x12{\n\x1a\x43onfigureMeasurementDigits\x12-.nidmm_grpc.ConfigureMeasurementDigitsRequest\x1a..nidmm_grpc.ConfigureMeasurementDigitsResponse\x12\x66\n\x13\x43onfigureMultiPoint\x12&.nidmm_grpc.ConfigureMultiPointRequest\x1a\'.nidmm_grpc.ConfigureMultiPointResponse\x12r\n\x17\x43onfigureOffsetCompOhms\x12*.nidmm_grpc.ConfigureOffsetCompOhmsRequest\x1a+.nidmm_grpc.ConfigureOffsetCompOhmsResponse\x12\x81\x01\n\x1c\x43onfigureOpenCableCompValues\x12/.nidmm_grpc.ConfigureOpenCableCompValuesRequest\x1a\x30.nidmm_grpc.ConfigureOpenCableCompValuesResponse\x12~\n\x1b\x43onfigurePowerLineFrequency\x12..nidmm_grpc.ConfigurePowerLineFrequencyRequest\x1a/.nidmm_grpc.ConfigurePowerLineFrequencyResponse\x12\x63\n\x12\x43onfigureRTDCustom\x12%.nidmm_grpc.ConfigureRTDCustomRequest\x1a&.nidmm_grpc.ConfigureRTDCustomResponse\x12]\n\x10\x43onfigureRTDType\x12#.nidmm_grpc.ConfigureRTDTypeRequest\x1a$.nidmm_grpc.ConfigureRTDTypeResponse\x12~\n\x1b\x43onfigureSampleTriggerSlope\x12..nidmm_grpc.ConfigureSampleTriggerSlopeRequest\x1a/.nidmm_grpc.ConfigureSampleTriggerSlopeResponse\x12\x84\x01\n\x1d\x43onfigureShortCableCompValues\x12\x30.nidmm_grpc.ConfigureShortCableCompValuesRequest\x1a\x31.nidmm_grpc.ConfigureShortCableCompValuesResponse\x12x\n\x19\x43onfigureThermistorCustom\x12,.nidmm_grpc.ConfigureThermistorCustomRequest\x1a-.nidmm_grpc.ConfigureThermistorCustomResponse\x12r\n\x17\x43onfigureThermistorType\x12*.nidmm_grpc.ConfigureThermistorTypeRequest\x1a+.nidmm_grpc.ConfigureThermistorTypeResponse\x12l\n\x15\x43onfigureThermocouple\x12(.nidmm_grpc.ConfigureThermocoupleRequest\x1a).nidmm_grpc.ConfigureThermocoupleResponse\x12r\n\x17\x43onfigureTransducerType\x12*.nidmm_grpc.ConfigureTransducerTypeRequest\x1a+.nidmm_grpc.ConfigureTransducerTypeResponse\x12]\n\x10\x43onfigureTrigger\x12#.nidmm_grpc.ConfigureTriggerRequest\x1a$.nidmm_grpc.ConfigureTriggerResponse\x12l\n\x15\x43onfigureTriggerSlope\x12(.nidmm_grpc.ConfigureTriggerSlopeRequest\x1a).nidmm_grpc.ConfigureTriggerSlopeResponse\x12\x81\x01\n\x1c\x43onfigureWaveformAcquisition\x12/.nidmm_grpc.ConfigureWaveformAcquisitionRequest\x1a\x30.nidmm_grpc.ConfigureWaveformAcquisitionResponse\x12x\n\x19\x43onfigureWaveformCoupling\x12,.nidmm_grpc.ConfigureWaveformCouplingRequest\x1a-.nidmm_grpc.ConfigureWaveformCouplingResponse\x12\x42\n\x07\x43ontrol\x12\x1a.nidmm_grpc.ControlRequest\x1a\x1b.nidmm_grpc.ControlResponse\x12\x42\n\x07\x44isable\x12\x1a.nidmm_grpc.DisableRequest\x1a\x1b.nidmm_grpc.DisableResponse\x12\x93\x01\n\"ExportAttributeConfigurationBuffer\x12\x35.nidmm_grpc.ExportAttributeConfigurationBufferRequest\x1a\x36.nidmm_grpc.ExportAttributeConfigurationBufferResponse\x12\x8d\x01\n ExportAttributeConfigurationFile\x12\x33.nidmm_grpc.ExportAttributeConfigurationFileRequest\x1a\x34.nidmm_grpc.ExportAttributeConfigurationFileResponse\x12<\n\x05\x46\x65tch\x12\x18.nidmm_grpc.FetchRequest\x1a\x19.nidmm_grpc.FetchResponse\x12Z\n\x0f\x46\x65tchMultiPoint\x12\".nidmm_grpc.FetchMultiPointRequest\x1a#.nidmm_grpc.FetchMultiPointResponse\x12T\n\rFetchWaveform\x12 .nidmm_grpc.FetchWaveformRequest\x1a!.nidmm_grpc.FetchWaveformResponse\x12\x66\n\x13GetApertureTimeInfo\x12&.nidmm_grpc.GetApertureTimeInfoRequest\x1a\'.nidmm_grpc.GetApertureTimeInfoResponse\x12l\n\x15GetAttributeViBoolean\x12(.nidmm_grpc.GetAttributeViBooleanRequest\x1a).nidmm_grpc.GetAttributeViBooleanResponse\x12\x66\n\x13GetAttributeViInt32\x12&.nidmm_grpc.GetAttributeViInt32Request\x1a\'.nidmm_grpc.GetAttributeViInt32Response\x12i\n\x14GetAttributeViReal64\x12\'.nidmm_grpc.GetAttributeViReal64Request\x1a(.nidmm_grpc.GetAttributeViReal64Response\x12l\n\x15GetAttributeViSession\x12(.nidmm_grpc.GetAttributeViSessionRequest\x1a).nidmm_grpc.GetAttributeViSessionResponse\x12i\n\x14GetAttributeViString\x12\'.nidmm_grpc.GetAttributeViStringRequest\x1a(.nidmm_grpc.GetAttributeViStringResponse\x12`\n\x11GetAutoRangeValue\x12$.nidmm_grpc.GetAutoRangeValueRequest\x1a%.nidmm_grpc.GetAutoRangeValueResponse\x12`\n\x11GetCalDateAndTime\x12$.nidmm_grpc.GetCalDateAndTimeRequest\x1a%.nidmm_grpc.GetCalDateAndTimeResponse\x12W\n\x0eGetChannelName\x12!.nidmm_grpc.GetChannelNameRequest\x1a\".nidmm_grpc.GetChannelNameResponse\x12K\n\nGetDevTemp\x12\x1d.nidmm_grpc.GetDevTempRequest\x1a\x1e.nidmm_grpc.GetDevTempResponse\x12\x45\n\x08GetError\x12\x1b.nidmm_grpc.GetErrorRequest\x1a\x1c.nidmm_grpc.GetErrorResponse\x12Z\n\x0fGetErrorMessage\x12\".nidmm_grpc.GetErrorMessageRequest\x1a#.nidmm_grpc.GetErrorMessageResponse\x12\x81\x01\n\x1cGetExtCalRecommendedInterval\x12/.nidmm_grpc.GetExtCalRecommendedIntervalRequest\x1a\x30.nidmm_grpc.GetExtCalRecommendedIntervalResponse\x12W\n\x0eGetLastCalTemp\x12!.nidmm_grpc.GetLastCalTempRequest\x1a\".nidmm_grpc.GetLastCalTempResponse\x12i\n\x14GetMeasurementPeriod\x12\'.nidmm_grpc.GetMeasurementPeriodRequest\x1a(.nidmm_grpc.GetMeasurementPeriodResponse\x12l\n\x15GetNextCoercionRecord\x12(.nidmm_grpc.GetNextCoercionRecordRequest\x1a).nidmm_grpc.GetNextCoercionRecordResponse\x12x\n\x19GetNextInterchangeWarning\x12,.nidmm_grpc.GetNextInterchangeWarningRequest\x1a-.nidmm_grpc.GetNextInterchangeWarningResponse\x12\x66\n\x13GetSelfCalSupported\x12&.nidmm_grpc.GetSelfCalSupportedRequest\x1a\'.nidmm_grpc.GetSelfCalSupportedResponse\x12\x93\x01\n\"ImportAttributeConfigurationBuffer\x12\x35.nidmm_grpc.ImportAttributeConfigurationBufferRequest\x1a\x36.nidmm_grpc.ImportAttributeConfigurationBufferResponse\x12\x8d\x01\n ImportAttributeConfigurationFile\x12\x33.nidmm_grpc.ImportAttributeConfigurationFileRequest\x1a\x34.nidmm_grpc.ImportAttributeConfigurationFileResponse\x12\x39\n\x04Init\x12\x17.nidmm_grpc.InitRequest\x1a\x18.nidmm_grpc.InitResponse\x12Z\n\x0fInitWithOptions\x12\".nidmm_grpc.InitWithOptionsRequest\x1a#.nidmm_grpc.InitWithOptionsResponse\x12\x45\n\x08Initiate\x12\x1b.nidmm_grpc.InitiateRequest\x1a\x1c.nidmm_grpc.InitiateResponse\x12r\n\x17InvalidateAllAttributes\x12*.nidmm_grpc.InvalidateAllAttributesRequest\x1a+.nidmm_grpc.InvalidateAllAttributesResponse\x12N\n\x0bIsOverRange\x12\x1e.nidmm_grpc.IsOverRangeRequest\x1a\x1f.nidmm_grpc.IsOverRangeResponse\x12Q\n\x0cIsUnderRange\x12\x1f.nidmm_grpc.IsUnderRangeRequest\x1a .nidmm_grpc.IsUnderRangeResponse\x12i\n\x14PerformOpenCableComp\x12\'.nidmm_grpc.PerformOpenCableCompRequest\x1a(.nidmm_grpc.PerformOpenCableCompResponse\x12l\n\x15PerformShortCableComp\x12(.nidmm_grpc.PerformShortCableCompRequest\x1a).nidmm_grpc.PerformShortCableCompResponse\x12\x39\n\x04Read\x12\x17.nidmm_grpc.ReadRequest\x1a\x18.nidmm_grpc.ReadResponse\x12W\n\x0eReadMultiPoint\x12!.nidmm_grpc.ReadMultiPointRequest\x1a\".nidmm_grpc.ReadMultiPointResponse\x12K\n\nReadStatus\x12\x1d.nidmm_grpc.ReadStatusRequest\x1a\x1e.nidmm_grpc.ReadStatusResponse\x12Q\n\x0cReadWaveform\x12\x1f.nidmm_grpc.ReadWaveformRequest\x1a .nidmm_grpc.ReadWaveformResponse\x12<\n\x05Reset\x12\x18.nidmm_grpc.ResetRequest\x1a\x19.nidmm_grpc.ResetResponse\x12l\n\x15ResetInterchangeCheck\x12(.nidmm_grpc.ResetInterchangeCheckRequest\x1a).nidmm_grpc.ResetInterchangeCheckResponse\x12`\n\x11ResetWithDefaults\x12$.nidmm_grpc.ResetWithDefaultsRequest\x1a%.nidmm_grpc.ResetWithDefaultsResponse\x12T\n\rRevisionQuery\x12 .nidmm_grpc.RevisionQueryRequest\x1a!.nidmm_grpc.RevisionQueryResponse\x12\x42\n\x07SelfCal\x12\x1a.nidmm_grpc.SelfCalRequest\x1a\x1b.nidmm_grpc.SelfCalResponse\x12\x45\n\x08SelfTest\x12\x1b.nidmm_grpc.SelfTestRequest\x1a\x1c.nidmm_grpc.SelfTestResponse\x12\x66\n\x13SendSoftwareTrigger\x12&.nidmm_grpc.SendSoftwareTriggerRequest\x1a\'.nidmm_grpc.SendSoftwareTriggerResponse\x12l\n\x15SetAttributeViBoolean\x12(.nidmm_grpc.SetAttributeViBooleanRequest\x1a).nidmm_grpc.SetAttributeViBooleanResponse\x12\x66\n\x13SetAttributeViInt32\x12&.nidmm_grpc.SetAttributeViInt32Request\x1a\'.nidmm_grpc.SetAttributeViInt32Response\x12i\n\x14SetAttributeViReal64\x12\'.nidmm_grpc.SetAttributeViReal64Request\x1a(.nidmm_grpc.SetAttributeViReal64Response\x12l\n\x15SetAttributeViSession\x12(.nidmm_grpc.SetAttributeViSessionRequest\x1a).nidmm_grpc.SetAttributeViSessionResponse\x12i\n\x14SetAttributeViString\x12\'.nidmm_grpc.SetAttributeViStringRequest\x1a(.nidmm_grpc.SetAttributeViStringResponseB9\n\x0f\x63om.ni.grpc.dmmB\x05NiDmmP\x01\xaa\x02\x1cNationalInstruments.Grpc.Dmmb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nidmm_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\017com.ni.grpc.dmmB\005NiDmmP\001\252\002\034NationalInstruments.Grpc.Dmm'
  _NIDMMINT32ATTRIBUTEVALUES._options = None
  _NIDMMINT32ATTRIBUTEVALUES._serialized_options = b'\020\001'
  _NIDMMREAL64ATTRIBUTEVALUES._options = None
  _NIDMMREAL64ATTRIBUTEVALUES._serialized_options = b'\020\001'
  _INITRESPONSE.fields_by_name['error_message']._options = None
  _INITRESPONSE.fields_by_name['error_message']._serialized_options = b'\030\001'
  _INITWITHOPTIONSRESPONSE.fields_by_name['error_message']._options = None
  _INITWITHOPTIONSRESPONSE.fields_by_name['error_message']._serialized_options = b'\030\001'
  _NIDMMATTRIBUTE._serialized_start=17337
  _NIDMMATTRIBUTE._serialized_end=20803
  _ACQUISITIONSTATUS._serialized_start=20806
  _ACQUISITIONSTATUS._serialized_end=21098
  _APERTURETIME._serialized_start=21101
  _APERTURETIME._serialized_end=21454
  _APERTURETIMEUNITS._serialized_start=21456
  _APERTURETIMEUNITS._serialized_end=21571
  _CALIBRATIONTYPE._serialized_start=21573
  _CALIBRATIONTYPE._serialized_end=21682
  _COMPENSATEDOHMS._serialized_start=21684
  _COMPENSATEDOHMS._serialized_end=21806
  _CONTROLCOMMIT._serialized_start=21808
  _CONTROLCOMMIT._serialized_end=21868
  _FREQUENCYVOLTAGERANGE._serialized_start=21871
  _FREQUENCYVOLTAGERANGE._serialized_end=22060
  _FUNCTION._serialized_start=22063
  _FUNCTION._serialized_end=22634
  _NIDMMINT32ATTRIBUTEVALUES._serialized_start=22637
  _NIDMMINT32ATTRIBUTEVALUES._serialized_end=28607
  _NIDMMREAL64ATTRIBUTEVALUES._serialized_start=28610
  _NIDMMREAL64ATTRIBUTEVALUES._serialized_end=29678
  _NIDMMREAL64ATTRIBUTEVALUESMAPPED._serialized_start=29681
  _NIDMMREAL64ATTRIBUTEVALUESMAPPED._serialized_end=30109
  _POWERLINEFREQUENCIES._serialized_start=30112
  _POWERLINEFREQUENCIES._serialized_end=30268
  _RTDTYPE._serialized_start=30271
  _RTDTYPE._serialized_end=30560
  _SAMPLECOUNT._serialized_start=30562
  _SAMPLECOUNT._serialized_end=30625
  _SAMPLEINTERVAL._serialized_start=30627
  _SAMPLEINTERVAL._serialized_end=30727
  _SAMPLETRIGSLOPE._serialized_start=30729
  _SAMPLETRIGSLOPE._serialized_end=30830
  _SAMPLETRIGGER._serialized_start=30833
  _SAMPLETRIGGER._serialized_end=31484
  _THERMOCOUPLEREFERENCEJUNCTIONTYPE._serialized_start=31487
  _THERMOCOUPLEREFERENCEJUNCTIONTYPE._serialized_end=31648
  _THERMOCOUPLETYPE._serialized_start=31651
  _THERMOCOUPLETYPE._serialized_end=32048
  _TIMELIMIT._serialized_start=32050
  _TIMELIMIT._serialized_end=32140
  _TRIGGERCOUNT._serialized_start=32142
  _TRIGGERCOUNT._serialized_end=32205
  _TRIGGERDELAYS._serialized_start=32208
  _TRIGGERDELAYS._serialized_end=32362
  _TRIGGERSLOPE._serialized_start=32364
  _TRIGGERSLOPE._serialized_end=32454
  _TRIGGERSOURCE._serialized_start=32457
  _TRIGGERSOURCE._serialized_end=33069
  _ABORTREQUEST._serialized_start=42
  _ABORTREQUEST._serialized_end=92
  _ABORTRESPONSE._serialized_start=94
  _ABORTRESPONSE._serialized_end=125
  _CHECKATTRIBUTEVIBOOLEANREQUEST._serialized_start=128
  _CHECKATTRIBUTEVIBOOLEANREQUEST._serialized_end=293
  _CHECKATTRIBUTEVIBOOLEANRESPONSE._serialized_start=295
  _CHECKATTRIBUTEVIBOOLEANRESPONSE._serialized_end=344
  _CHECKATTRIBUTEVIINT32REQUEST._serialized_start=347
  _CHECKATTRIBUTEVIINT32REQUEST._serialized_end=606
  _CHECKATTRIBUTEVIINT32RESPONSE._serialized_start=608
  _CHECKATTRIBUTEVIINT32RESPONSE._serialized_end=655
  _CHECKATTRIBUTEVIREAL64REQUEST._serialized_start=658
  _CHECKATTRIBUTEVIREAL64REQUEST._serialized_end=999
  _CHECKATTRIBUTEVIREAL64RESPONSE._serialized_start=1001
  _CHECKATTRIBUTEVIREAL64RESPONSE._serialized_end=1049
  _CHECKATTRIBUTEVISESSIONREQUEST._serialized_start=1052
  _CHECKATTRIBUTEVISESSIONREQUEST._serialized_end=1241
  _CHECKATTRIBUTEVISESSIONRESPONSE._serialized_start=1243
  _CHECKATTRIBUTEVISESSIONRESPONSE._serialized_end=1292
  _CHECKATTRIBUTEVISTRINGREQUEST._serialized_start=1295
  _CHECKATTRIBUTEVISTRINGREQUEST._serialized_end=1463
  _CHECKATTRIBUTEVISTRINGRESPONSE._serialized_start=1465
  _CHECKATTRIBUTEVISTRINGRESPONSE._serialized_end=1513
  _CLEARERRORREQUEST._serialized_start=1515
  _CLEARERRORREQUEST._serialized_end=1570
  _CLEARERRORRESPONSE._serialized_start=1572
  _CLEARERRORRESPONSE._serialized_end=1608
  _CLEARINTERCHANGEWARNINGSREQUEST._serialized_start=1610
  _CLEARINTERCHANGEWARNINGSREQUEST._serialized_end=1679
  _CLEARINTERCHANGEWARNINGSRESPONSE._serialized_start=1681
  _CLEARINTERCHANGEWARNINGSRESPONSE._serialized_end=1731
  _CLOSEREQUEST._serialized_start=1733
  _CLOSEREQUEST._serialized_end=1783
  _CLOSERESPONSE._serialized_start=1785
  _CLOSERESPONSE._serialized_end=1816
  _CONFIGUREACBANDWIDTHREQUEST._serialized_start=1819
  _CONFIGUREACBANDWIDTHREQUEST._serialized_end=1950
  _CONFIGUREACBANDWIDTHRESPONSE._serialized_start=1952
  _CONFIGUREACBANDWIDTHRESPONSE._serialized_end=1998
  _CONFIGUREADCCALIBRATIONREQUEST._serialized_start=2000
  _CONFIGUREADCCALIBRATIONREQUEST._serialized_end=2093
  _CONFIGUREADCCALIBRATIONRESPONSE._serialized_start=2095
  _CONFIGUREADCCALIBRATIONRESPONSE._serialized_end=2144
  _CONFIGUREAUTOZEROMODEREQUEST._serialized_start=2146
  _CONFIGUREAUTOZEROMODEREQUEST._serialized_end=2236
  _CONFIGUREAUTOZEROMODERESPONSE._serialized_start=2238
  _CONFIGUREAUTOZEROMODERESPONSE._serialized_end=2285
  _CONFIGURECABLECOMPTYPEREQUEST._serialized_start=2287
  _CONFIGURECABLECOMPTYPEREQUEST._serialized_end=2379
  _CONFIGURECABLECOMPTYPERESPONSE._serialized_start=2381
  _CONFIGURECABLECOMPTYPERESPONSE._serialized_end=2429
  _CONFIGURECURRENTSOURCEREQUEST._serialized_start=2431
  _CONFIGURECURRENTSOURCEREQUEST._serialized_end=2522
  _CONFIGURECURRENTSOURCERESPONSE._serialized_start=2524
  _CONFIGURECURRENTSOURCERESPONSE._serialized_end=2572
  _CONFIGUREFIXEDREFJUNCTIONREQUEST._serialized_start=2574
  _CONFIGUREFIXEDREFJUNCTIONREQUEST._serialized_end=2678
  _CONFIGUREFIXEDREFJUNCTIONRESPONSE._serialized_start=2680
  _CONFIGUREFIXEDREFJUNCTIONRESPONSE._serialized_end=2731
  _CONFIGUREFREQUENCYVOLTAGERANGEREQUEST._serialized_start=2734
  _CONFIGUREFREQUENCYVOLTAGERANGEREQUEST._serialized_end=2920
  _CONFIGUREFREQUENCYVOLTAGERANGERESPONSE._serialized_start=2922
  _CONFIGUREFREQUENCYVOLTAGERANGERESPONSE._serialized_end=2978
  _CONFIGUREMEASCOMPLETEDESTREQUEST._serialized_start=2980
  _CONFIGUREMEASCOMPLETEDESTREQUEST._serialized_end=3085
  _CONFIGUREMEASCOMPLETEDESTRESPONSE._serialized_start=3087
  _CONFIGUREMEASCOMPLETEDESTRESPONSE._serialized_end=3138
  _CONFIGUREMEASCOMPLETESLOPEREQUEST._serialized_start=3140
  _CONFIGUREMEASCOMPLETESLOPEREQUEST._serialized_end=3240
  _CONFIGUREMEASCOMPLETESLOPERESPONSE._serialized_start=3242
  _CONFIGUREMEASCOMPLETESLOPERESPONSE._serialized_end=3294
  _CONFIGUREMEASUREMENTABSOLUTEREQUEST._serialized_start=3297
  _CONFIGUREMEASUREMENTABSOLUTEREQUEST._serialized_end=3533
  _CONFIGUREMEASUREMENTABSOLUTERESPONSE._serialized_start=3535
  _CONFIGUREMEASUREMENTABSOLUTERESPONSE._serialized_end=3589
  _CONFIGUREMEASUREMENTDIGITSREQUEST._serialized_start=3592
  _CONFIGUREMEASUREMENTDIGITSREQUEST._serialized_end=3824
  _CONFIGUREMEASUREMENTDIGITSRESPONSE._serialized_start=3826
  _CONFIGUREMEASUREMENTDIGITSRESPONSE._serialized_end=3878
  _CONFIGUREMULTIPOINTREQUEST._serialized_start=3881
  _CONFIGUREMULTIPOINTREQUEST._serialized_end=4361
  _CONFIGUREMULTIPOINTRESPONSE._serialized_start=4363
  _CONFIGUREMULTIPOINTRESPONSE._serialized_end=4408
  _CONFIGUREOFFSETCOMPOHMSREQUEST._serialized_start=4411
  _CONFIGUREOFFSETCOMPOHMSREQUEST._serialized_end=4593
  _CONFIGUREOFFSETCOMPOHMSRESPONSE._serialized_start=4595
  _CONFIGUREOFFSETCOMPOHMSRESPONSE._serialized_end=4644
  _CONFIGUREOPENCABLECOMPVALUESREQUEST._serialized_start=4646
  _CONFIGUREOPENCABLECOMPVALUESREQUEST._serialized_end=4761
  _CONFIGUREOPENCABLECOMPVALUESRESPONSE._serialized_start=4763
  _CONFIGUREOPENCABLECOMPVALUESRESPONSE._serialized_end=4817
  _CONFIGUREPOWERLINEFREQUENCYREQUEST._serialized_start=4820
  _CONFIGUREPOWERLINEFREQUENCYREQUEST._serialized_end=5032
  _CONFIGUREPOWERLINEFREQUENCYRESPONSE._serialized_start=5034
  _CONFIGUREPOWERLINEFREQUENCYRESPONSE._serialized_end=5087
  _CONFIGURERTDCUSTOMREQUEST._serialized_start=5089
  _CONFIGURERTDCUSTOMREQUEST._serialized_end=5197
  _CONFIGURERTDCUSTOMRESPONSE._serialized_start=5199
  _CONFIGURERTDCUSTOMRESPONSE._serialized_end=5243
  _CONFIGURERTDTYPEREQUEST._serialized_start=5246
  _CONFIGURERTDTYPEREQUEST._serialized_end=5413
  _CONFIGURERTDTYPERESPONSE._serialized_start=5415
  _CONFIGURERTDTYPERESPONSE._serialized_end=5457
  _CONFIGURESAMPLETRIGGERSLOPEREQUEST._serialized_start=5460
  _CONFIGURESAMPLETRIGGERSLOPEREQUEST._serialized_end=5658
  _CONFIGURESAMPLETRIGGERSLOPERESPONSE._serialized_start=5660
  _CONFIGURESAMPLETRIGGERSLOPERESPONSE._serialized_end=5713
  _CONFIGURESHORTCABLECOMPVALUESREQUEST._serialized_start=5715
  _CONFIGURESHORTCABLECOMPVALUESREQUEST._serialized_end=5828
  _CONFIGURESHORTCABLECOMPVALUESRESPONSE._serialized_start=5830
  _CONFIGURESHORTCABLECOMPVALUESRESPONSE._serialized_end=5885
  _CONFIGURETHERMISTORCUSTOMREQUEST._serialized_start=5888
  _CONFIGURETHERMISTORCUSTOMREQUEST._serialized_end=6024
  _CONFIGURETHERMISTORCUSTOMRESPONSE._serialized_start=6026
  _CONFIGURETHERMISTORCUSTOMRESPONSE._serialized_end=6077
  _CONFIGURETHERMISTORTYPEREQUEST._serialized_start=6079
  _CONFIGURETHERMISTORTYPEREQUEST._serialized_end=6172
  _CONFIGURETHERMISTORTYPERESPONSE._serialized_start=6174
  _CONFIGURETHERMISTORTYPERESPONSE._serialized_end=6223
  _CONFIGURETHERMOCOUPLEREQUEST._serialized_start=6226
  _CONFIGURETHERMOCOUPLEREQUEST._serialized_end=6563
  _CONFIGURETHERMOCOUPLERESPONSE._serialized_start=6565
  _CONFIGURETHERMOCOUPLERESPONSE._serialized_end=6612
  _CONFIGURETRANSDUCERTYPEREQUEST._serialized_start=6614
  _CONFIGURETRANSDUCERTYPEREQUEST._serialized_end=6707
  _CONFIGURETRANSDUCERTYPERESPONSE._serialized_start=6709
  _CONFIGURETRANSDUCERTYPERESPONSE._serialized_end=6758
  _CONFIGURETRIGGERREQUEST._serialized_start=6761
  _CONFIGURETRIGGERREQUEST._serialized_end=7031
  _CONFIGURETRIGGERRESPONSE._serialized_start=7033
  _CONFIGURETRIGGERRESPONSE._serialized_end=7075
  _CONFIGURETRIGGERSLOPEREQUEST._serialized_start=7078
  _CONFIGURETRIGGERSLOPEREQUEST._serialized_end=7246
  _CONFIGURETRIGGERSLOPERESPONSE._serialized_start=7248
  _CONFIGURETRIGGERSLOPERESPONSE._serialized_end=7295
  _CONFIGUREWAVEFORMACQUISITIONREQUEST._serialized_start=7298
  _CONFIGUREWAVEFORMACQUISITIONREQUEST._serialized_end=7544
  _CONFIGUREWAVEFORMACQUISITIONRESPONSE._serialized_start=7546
  _CONFIGUREWAVEFORMACQUISITIONRESPONSE._serialized_end=7600
  _CONFIGUREWAVEFORMCOUPLINGREQUEST._serialized_start=7602
  _CONFIGUREWAVEFORMCOUPLINGREQUEST._serialized_end=7699
  _CONFIGUREWAVEFORMCOUPLINGRESPONSE._serialized_start=7701
  _CONFIGUREWAVEFORMCOUPLINGRESPONSE._serialized_end=7752
  _CONTROLREQUEST._serialized_start=7755
  _CONTROLREQUEST._serialized_end=7913
  _CONTROLRESPONSE._serialized_start=7915
  _CONTROLRESPONSE._serialized_end=7948
  _DISABLEREQUEST._serialized_start=7950
  _DISABLEREQUEST._serialized_end=8002
  _DISABLERESPONSE._serialized_start=8004
  _DISABLERESPONSE._serialized_end=8037
  _EXPORTATTRIBUTECONFIGURATIONBUFFERREQUEST._serialized_start=8039
  _EXPORTATTRIBUTECONFIGURATIONBUFFERREQUEST._serialized_end=8118
  _EXPORTATTRIBUTECONFIGURATIONBUFFERRESPONSE._serialized_start=8120
  _EXPORTATTRIBUTECONFIGURATIONBUFFERRESPONSE._serialized_end=8203
  _EXPORTATTRIBUTECONFIGURATIONFILEREQUEST._serialized_start=8205
  _EXPORTATTRIBUTECONFIGURATIONFILEREQUEST._serialized_end=8301
  _EXPORTATTRIBUTECONFIGURATIONFILERESPONSE._serialized_start=8303
  _EXPORTATTRIBUTECONFIGURATIONFILERESPONSE._serialized_end=8361
  _FETCHREQUEST._serialized_start=8364
  _FETCHREQUEST._serialized_end=8510
  _FETCHRESPONSE._serialized_start=8512
  _FETCHRESPONSE._serialized_end=8560
  _FETCHMULTIPOINTREQUEST._serialized_start=8563
  _FETCHMULTIPOINTREQUEST._serialized_end=8739
  _FETCHMULTIPOINTRESPONSE._serialized_start=8741
  _FETCHMULTIPOINTRESPONSE._serialized_end=8838
  _FETCHWAVEFORMREQUEST._serialized_start=8841
  _FETCHWAVEFORMREQUEST._serialized_end=9015
  _FETCHWAVEFORMRESPONSE._serialized_start=9017
  _FETCHWAVEFORMRESPONSE._serialized_end=9113
  _GETAPERTURETIMEINFOREQUEST._serialized_start=9115
  _GETAPERTURETIMEINFOREQUEST._serialized_end=9179
  _GETAPERTURETIMEINFORESPONSE._serialized_start=9182
  _GETAPERTURETIMEINFORESPONSE._serialized_end=9396
  _GETATTRIBUTEVIBOOLEANREQUEST._serialized_start=9399
  _GETATTRIBUTEVIBOOLEANREQUEST._serialized_end=9537
  _GETATTRIBUTEVIBOOLEANRESPONSE._serialized_start=9539
  _GETATTRIBUTEVIBOOLEANRESPONSE._serialized_end=9611
  _GETATTRIBUTEVIINT32REQUEST._serialized_start=9614
  _GETATTRIBUTEVIINT32REQUEST._serialized_end=9750
  _GETATTRIBUTEVIINT32RESPONSE._serialized_start=9752
  _GETATTRIBUTEVIINT32RESPONSE._serialized_end=9822
  _GETATTRIBUTEVIREAL64REQUEST._serialized_start=9825
  _GETATTRIBUTEVIREAL64REQUEST._serialized_end=9962
  _GETATTRIBUTEVIREAL64RESPONSE._serialized_start=9964
  _GETATTRIBUTEVIREAL64RESPONSE._serialized_end=10035
  _GETATTRIBUTEVISESSIONREQUEST._serialized_start=10038
  _GETATTRIBUTEVISESSIONREQUEST._serialized_end=10176
  _GETATTRIBUTEVISESSIONRESPONSE._serialized_start=10178
  _GETATTRIBUTEVISESSIONRESPONSE._serialized_end=10274
  _GETATTRIBUTEVISTRINGREQUEST._serialized_start=10277
  _GETATTRIBUTEVISTRINGREQUEST._serialized_end=10414
  _GETATTRIBUTEVISTRINGRESPONSE._serialized_start=10416
  _GETATTRIBUTEVISTRINGRESPONSE._serialized_end=10487
  _GETAUTORANGEVALUEREQUEST._serialized_start=10489
  _GETAUTORANGEVALUEREQUEST._serialized_end=10551
  _GETAUTORANGEVALUERESPONSE._serialized_start=10553
  _GETAUTORANGEVALUERESPONSE._serialized_end=10618
  _GETCALDATEANDTIMEREQUEST._serialized_start=10621
  _GETCALDATEANDTIMEREQUEST._serialized_end=10773
  _GETCALDATEANDTIMERESPONSE._serialized_start=10775
  _GETCALDATEANDTIMERESPONSE._serialized_end=10890
  _GETCHANNELNAMEREQUEST._serialized_start=10892
  _GETCHANNELNAMEREQUEST._serialized_end=10966
  _GETCHANNELNAMERESPONSE._serialized_start=10968
  _GETCHANNELNAMERESPONSE._serialized_end=11032
  _GETDEVTEMPREQUEST._serialized_start=11034
  _GETDEVTEMPREQUEST._serialized_end=11106
  _GETDEVTEMPRESPONSE._serialized_start=11108
  _GETDEVTEMPRESPONSE._serialized_end=11165
  _GETERRORREQUEST._serialized_start=11167
  _GETERRORREQUEST._serialized_end=11220
  _GETERRORRESPONSE._serialized_start=11222
  _GETERRORRESPONSE._serialized_end=11297
  _GETERRORMESSAGEREQUEST._serialized_start=11299
  _GETERRORMESSAGEREQUEST._serialized_end=11379
  _GETERRORMESSAGERESPONSE._serialized_start=11381
  _GETERRORMESSAGERESPONSE._serialized_end=11445
  _GETEXTCALRECOMMENDEDINTERVALREQUEST._serialized_start=11447
  _GETEXTCALRECOMMENDEDINTERVALREQUEST._serialized_end=11520
  _GETEXTCALRECOMMENDEDINTERVALRESPONSE._serialized_start=11522
  _GETEXTCALRECOMMENDEDINTERVALRESPONSE._serialized_end=11592
  _GETLASTCALTEMPREQUEST._serialized_start=11595
  _GETLASTCALTEMPREQUEST._serialized_end=11744
  _GETLASTCALTEMPRESPONSE._serialized_start=11746
  _GETLASTCALTEMPRESPONSE._serialized_end=11807
  _GETMEASUREMENTPERIODREQUEST._serialized_start=11809
  _GETMEASUREMENTPERIODREQUEST._serialized_end=11874
  _GETMEASUREMENTPERIODRESPONSE._serialized_start=11876
  _GETMEASUREMENTPERIODRESPONSE._serialized_end=11938
  _GETNEXTCOERCIONRECORDREQUEST._serialized_start=11940
  _GETNEXTCOERCIONRECORDREQUEST._serialized_end=12006
  _GETNEXTCOERCIONRECORDRESPONSE._serialized_start=12008
  _GETNEXTCOERCIONRECORDRESPONSE._serialized_end=12080
  _GETNEXTINTERCHANGEWARNINGREQUEST._serialized_start=12082
  _GETNEXTINTERCHANGEWARNINGREQUEST._serialized_end=12152
  _GETNEXTINTERCHANGEWARNINGRESPONSE._serialized_start=12154
  _GETNEXTINTERCHANGEWARNINGRESPONSE._serialized_end=12234
  _GETSELFCALSUPPORTEDREQUEST._serialized_start=12236
  _GETSELFCALSUPPORTEDREQUEST._serialized_end=12300
  _GETSELFCALSUPPORTEDRESPONSE._serialized_start=12302
  _GETSELFCALSUPPORTEDRESPONSE._serialized_end=12375
  _IMPORTATTRIBUTECONFIGURATIONBUFFERREQUEST._serialized_start=12377
  _IMPORTATTRIBUTECONFIGURATIONBUFFERREQUEST._serialized_end=12479
  _IMPORTATTRIBUTECONFIGURATIONBUFFERRESPONSE._serialized_start=12481
  _IMPORTATTRIBUTECONFIGURATIONBUFFERRESPONSE._serialized_end=12541
  _IMPORTATTRIBUTECONFIGURATIONFILEREQUEST._serialized_start=12543
  _IMPORTATTRIBUTECONFIGURATIONFILEREQUEST._serialized_end=12639
  _IMPORTATTRIBUTECONFIGURATIONFILERESPONSE._serialized_start=12641
  _IMPORTATTRIBUTECONFIGURATIONFILERESPONSE._serialized_end=12699
  _INITREQUEST._serialized_start=12702
  _INITREQUEST._serialized_end=12879
  _INITRESPONSE._serialized_start=12881
  _INITRESPONSE._serialized_end=13007
  _INITWITHOPTIONSREQUEST._serialized_start=13010
  _INITWITHOPTIONSREQUEST._serialized_end=13221
  _INITWITHOPTIONSRESPONSE._serialized_start=13224
  _INITWITHOPTIONSRESPONSE._serialized_end=13361
  _INITIATEREQUEST._serialized_start=13363
  _INITIATEREQUEST._serialized_end=13416
  _INITIATERESPONSE._serialized_start=13418
  _INITIATERESPONSE._serialized_end=13452
  _INVALIDATEALLATTRIBUTESREQUEST._serialized_start=13454
  _INVALIDATEALLATTRIBUTESREQUEST._serialized_end=13522
  _INVALIDATEALLATTRIBUTESRESPONSE._serialized_start=13524
  _INVALIDATEALLATTRIBUTESRESPONSE._serialized_end=13573
  _ISOVERRANGEREQUEST._serialized_start=13575
  _ISOVERRANGEREQUEST._serialized_end=13658
  _ISOVERRANGERESPONSE._serialized_start=13660
  _ISOVERRANGERESPONSE._serialized_end=13720
  _ISUNDERRANGEREQUEST._serialized_start=13722
  _ISUNDERRANGEREQUEST._serialized_end=13806
  _ISUNDERRANGERESPONSE._serialized_start=13808
  _ISUNDERRANGERESPONSE._serialized_end=13870
  _PERFORMOPENCABLECOMPREQUEST._serialized_start=13872
  _PERFORMOPENCABLECOMPREQUEST._serialized_end=13937
  _PERFORMOPENCABLECOMPRESPONSE._serialized_start=13939
  _PERFORMOPENCABLECOMPRESPONSE._serialized_end=14027
  _PERFORMSHORTCABLECOMPREQUEST._serialized_start=14029
  _PERFORMSHORTCABLECOMPREQUEST._serialized_end=14095
  _PERFORMSHORTCABLECOMPRESPONSE._serialized_start=14097
  _PERFORMSHORTCABLECOMPRESPONSE._serialized_end=14183
  _READREQUEST._serialized_start=14186
  _READREQUEST._serialized_end=14331
  _READRESPONSE._serialized_start=14333
  _READRESPONSE._serialized_end=14380
  _READMULTIPOINTREQUEST._serialized_start=14383
  _READMULTIPOINTREQUEST._serialized_end=14558
  _READMULTIPOINTRESPONSE._serialized_start=14560
  _READMULTIPOINTRESPONSE._serialized_end=14656
  _READSTATUSREQUEST._serialized_start=14658
  _READSTATUSREQUEST._serialized_end=14713
  _READSTATUSRESPONSE._serialized_start=14716
  _READSTATUSRESPONSE._serialized_end=14872
  _READWAVEFORMREQUEST._serialized_start=14875
  _READWAVEFORMREQUEST._serialized_end=15048
  _READWAVEFORMRESPONSE._serialized_start=15050
  _READWAVEFORMRESPONSE._serialized_end=15145
  _RESETREQUEST._serialized_start=15147
  _RESETREQUEST._serialized_end=15197
  _RESETRESPONSE._serialized_start=15199
  _RESETRESPONSE._serialized_end=15230
  _RESETINTERCHANGECHECKREQUEST._serialized_start=15232
  _RESETINTERCHANGECHECKREQUEST._serialized_end=15298
  _RESETINTERCHANGECHECKRESPONSE._serialized_start=15300
  _RESETINTERCHANGECHECKRESPONSE._serialized_end=15347
  _RESETWITHDEFAULTSREQUEST._serialized_start=15349
  _RESETWITHDEFAULTSREQUEST._serialized_end=15411
  _RESETWITHDEFAULTSRESPONSE._serialized_start=15413
  _RESETWITHDEFAULTSRESPONSE._serialized_end=15456
  _REVISIONQUERYREQUEST._serialized_start=15458
  _REVISIONQUERYREQUEST._serialized_end=15516
  _REVISIONQUERYRESPONSE._serialized_start=15518
  _REVISIONQUERYRESPONSE._serialized_end=15620
  _SELFCALREQUEST._serialized_start=15622
  _SELFCALREQUEST._serialized_end=15674
  _SELFCALRESPONSE._serialized_start=15676
  _SELFCALRESPONSE._serialized_end=15709
  _SELFTESTREQUEST._serialized_start=15711
  _SELFTESTREQUEST._serialized_end=15764
  _SELFTESTRESPONSE._serialized_start=15766
  _SELFTESTRESPONSE._serialized_end=15853
  _SENDSOFTWARETRIGGERREQUEST._serialized_start=15855
  _SENDSOFTWARETRIGGERREQUEST._serialized_end=15919
  _SENDSOFTWARETRIGGERRESPONSE._serialized_start=15921
  _SENDSOFTWARETRIGGERRESPONSE._serialized_end=15966
  _SETATTRIBUTEVIBOOLEANREQUEST._serialized_start=15969
  _SETATTRIBUTEVIBOOLEANREQUEST._serialized_end=16132
  _SETATTRIBUTEVIBOOLEANRESPONSE._serialized_start=16134
  _SETATTRIBUTEVIBOOLEANRESPONSE._serialized_end=16181
  _SETATTRIBUTEVIINT32REQUEST._serialized_start=16184
  _SETATTRIBUTEVIINT32REQUEST._serialized_end=16441
  _SETATTRIBUTEVIINT32RESPONSE._serialized_start=16443
  _SETATTRIBUTEVIINT32RESPONSE._serialized_end=16488
  _SETATTRIBUTEVIREAL64REQUEST._serialized_start=16491
  _SETATTRIBUTEVIREAL64REQUEST._serialized_end=16830
  _SETATTRIBUTEVIREAL64RESPONSE._serialized_start=16832
  _SETATTRIBUTEVIREAL64RESPONSE._serialized_end=16878
  _SETATTRIBUTEVISESSIONREQUEST._serialized_start=16881
  _SETATTRIBUTEVISESSIONREQUEST._serialized_end=17068
  _SETATTRIBUTEVISESSIONRESPONSE._serialized_start=17070
  _SETATTRIBUTEVISESSIONRESPONSE._serialized_end=17117
  _SETATTRIBUTEVISTRINGREQUEST._serialized_start=17120
  _SETATTRIBUTEVISTRINGREQUEST._serialized_end=17286
  _SETATTRIBUTEVISTRINGRESPONSE._serialized_start=17288
  _SETATTRIBUTEVISTRINGRESPONSE._serialized_end=17334
  _NIDMM._serialized_start=33072
  _NIDMM._serialized_end=42110
# @@protoc_insertion_point(module_scope)
